# Copyright 2022 Keyfactor                                                   
# Licensed under the Apache License, Version 2.0 (the "License"); you may    
# not use this file except in compliance with the License.  You may obtain a 
# copy of the License at http://www.apache.org/licenses/LICENSE-2.0.  Unless 
# required by applicable law or agreed to in writing, software distributed   
# under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES   
# OR CONDITIONS OF ANY KIND, either express or implied. See the License for  
# the specific language governing permissions and limitations under the       
# License.
import base64
import json
import os
from datetime import datetime
import keyfactor_v_1_client as keyfactorSDK
import \
    keyfactor_v_1_client.api.certificate_authority.certificate_authority_delete_ca as kf_delete_ca
import keyfactor_v_1_client.api.certificate_authority.certificate_authority_get_ca as kf_get_ca
import \
    keyfactor_v_1_client.api.certificate_authority.certificate_authority_update_ca as kf_update_ca
import \
    keyfactor_v_1_client.api.certificate_authority.certificate_authority_create_ca as kf_create_ca
import \
    keyfactor_v_1_client.api.certificate_authority.certificate_authority_publish_crl as kf_publish_crl
import keyfactor_v_1_client.api.certificate_authority.certificate_authority_get_cas as kf_get_cas
import \
    keyfactor_v_1_client.api.certificate_authority.certificate_authority_test_certificate_authority as kf_test_certificate_authority
import \
    keyfactor_v_1_client.api.workflow_instance.workflow_instance_delete_instance as kf_delete_instance
import \
    keyfactor_v_1_client.api.workflow_instance.workflow_instance_query_instances_started_by_me as kf_query_instances_started_by_me
import keyfactor_v_1_client.api.workflow_instance.workflow_instance_restart as kf_restart
import keyfactor_v_1_client.api.workflow_instance.workflow_instance_query as kf_query
import keyfactor_v_1_client.api.workflow_instance.workflow_instance_get as kf_get
import keyfactor_v_1_client.api.workflow_instance.workflow_instance_stop as kf_stop
import \
    keyfactor_v_1_client.api.workflow_instance.workflow_instance_query_instances_assigned_to_me as kf_query_instances_assigned_to_me
import keyfactor_v_1_client.api.workflow_instance.workflow_instance_signal as kf_signal
import \
    keyfactor_v_1_client.api.security_role_permissions.security_role_permissions_get_collection_permissions_for_role as kf_get_collection_permissions_for_role
import \
    keyfactor_v_1_client.api.security_role_permissions.security_role_permissions_get_permissions_for_role as kf_get_permissions_for_role
import \
    keyfactor_v_1_client.api.security_role_permissions.security_role_permissions_set_container_permissions as kf_set_container_permissions
import \
    keyfactor_v_1_client.api.security_role_permissions.security_role_permissions_add_global_permissions as kf_add_global_permissions
import \
    keyfactor_v_1_client.api.security_role_permissions.security_role_permissions_get_global_permissions_for_role as kf_get_global_permissions_for_role
import \
    keyfactor_v_1_client.api.security_role_permissions.security_role_permissions_add_collection_permissions as kf_add_collection_permissions
import \
    keyfactor_v_1_client.api.security_role_permissions.security_role_permissions_set_collection_permissions as kf_set_collection_permissions
import \
    keyfactor_v_1_client.api.security_role_permissions.security_role_permissions_get_container_permissions_for_role as kf_get_container_permissions_for_role
import \
    keyfactor_v_1_client.api.security_role_permissions.security_role_permissions_set_global_permissions as kf_set_global_permissions
import \
    keyfactor_v_1_client.api.security_role_permissions.security_role_permissions_add_container_permissions as kf_add_container_permissions
import keyfactor_v_1_client.api.csr_generation.csr_generation_delete_cs_rs as kf_delete_cs_rs
import \
    keyfactor_v_1_client.api.csr_generation.csr_generation_get_pending_cs_rs as kf_get_pending_cs_rs
import keyfactor_v_1_client.api.csr_generation.csr_generation_post_generate as kf_post_generate
import keyfactor_v_1_client.api.csr_generation.csr_generation_delete_csr as kf_delete_csr
import keyfactor_v_1_client.api.csr_generation.csr_generation_download as kf_download
import keyfactor_v_1_client.api.logon.logon_create_logon as kf_create_logon
import keyfactor_v_1_client.api.logon.logon_query_logons as kf_query_logons
import keyfactor_v_1_client.api.logon.logon_delete as kf_delete
import keyfactor_v_1_client.api.logon.logon_get_logon as kf_get_logon
import keyfactor_v_1_client.api.logon.logon_logon_access as kf_logon_access
import \
    keyfactor_v_1_client.api.expiration_alert.expiration_alert_add_expiration_alert as kf_add_expiration_alert
import \
    keyfactor_v_1_client.api.expiration_alert.expiration_alert_delete_expiration_alert as kf_delete_expiration_alert
import \
    keyfactor_v_1_client.api.expiration_alert.expiration_alert_get_expiration_alert as kf_get_expiration_alert
import keyfactor_v_1_client.api.expiration_alert.expiration_alert_get_schedule as kf_get_schedule
import \
    keyfactor_v_1_client.api.expiration_alert.expiration_alert_edit_expiration_alert as kf_edit_expiration_alert
import \
    keyfactor_v_1_client.api.expiration_alert.expiration_alert_test_expiration_alert as kf_test_expiration_alert
import \
    keyfactor_v_1_client.api.expiration_alert.expiration_alert_get_expiration_alerts as kf_get_expiration_alerts
import keyfactor_v_1_client.api.expiration_alert.expiration_alert_edit_schedule as kf_edit_schedule
import \
    keyfactor_v_1_client.api.expiration_alert.expiration_alert_test_all_expiration_alert as kf_test_all_expiration_alert
import \
    keyfactor_v_1_client.api.service_account.service_account_rotate_service_account_key as kf_rotate_service_account_key
import \
    keyfactor_v_1_client.api.service_account.service_account_delete_service_account as kf_delete_service_account
import \
    keyfactor_v_1_client.api.service_account.service_account_delete_service_accounts as kf_delete_service_accounts
import \
    keyfactor_v_1_client.api.service_account.service_account_create_service_account as kf_create_service_account
import \
    keyfactor_v_1_client.api.service_account.service_account_query_service_accounts as kf_query_service_accounts
import \
    keyfactor_v_1_client.api.service_account.service_account_update_service_account as kf_update_service_account
import keyfactor_v_1_client.api.service_account.service_account_get as kf_get
import \
    keyfactor_v_1_client.api.service_account.service_account_get_service_account_key as kf_get_service_account_key
import keyfactor_v_1_client.api.audit_log.audit_log_get_audit_log as kf_get_audit_log
import keyfactor_v_1_client.api.audit_log.audit_log_get_audit_logs as kf_get_audit_logs
import keyfactor_v_1_client.api.audit_log.audit_log_validate_audit_log as kf_validate_audit_log
import keyfactor_v_1_client.api.audit_log.audit_log_download_csv as kf_download_csv
import keyfactor_v_1_client.api.audit_log.audit_log_get_related_entities as kf_get_related_entities
import \
    keyfactor_v_1_client.api.orchestrator_job.orchestrator_job_get_job_history as kf_get_job_history
import \
    keyfactor_v_1_client.api.orchestrator_job.orchestrator_job_unschedule_jobs as kf_unschedule_jobs
import \
    keyfactor_v_1_client.api.orchestrator_job.orchestrator_job_schedule_bulk_job as kf_schedule_bulk_job
import \
    keyfactor_v_1_client.api.orchestrator_job.orchestrator_job_get_scheduled_jobs as kf_get_scheduled_jobs
import \
    keyfactor_v_1_client.api.orchestrator_job.orchestrator_job_reschedule_jobs as kf_reschedule_jobs
import \
    keyfactor_v_1_client.api.orchestrator_job.orchestrator_job_get_custom_job_result_data as kf_get_custom_job_result_data
import keyfactor_v_1_client.api.orchestrator_job.orchestrator_job_schedule_job as kf_schedule_job
import \
    keyfactor_v_1_client.api.orchestrator_job.orchestrator_job_acknowledge_jobs as kf_acknowledge_jobs
import \
    keyfactor_v_1_client.api.certificate_store.certificate_store_update_certificate_store_server as kf_update_certificate_store_server
import keyfactor_v_1_client.api.certificate_store.certificate_store_schedule as kf_schedule
import \
    keyfactor_v_1_client.api.certificate_store.certificate_store_get_certificate_store_inventory as kf_get_certificate_store_inventory
import \
    keyfactor_v_1_client.api.certificate_store.certificate_store_configure_discovery_job as kf_configure_discovery_job
import \
    keyfactor_v_1_client.api.certificate_store.certificate_store_delete_certificate_store as kf_delete_certificate_store
import keyfactor_v_1_client.api.certificate_store.certificate_store_set_password as kf_set_password
import \
    keyfactor_v_1_client.api.certificate_store.certificate_store_approve_pending as kf_approve_pending
import \
    keyfactor_v_1_client.api.certificate_store.certificate_store_create_certificate_store_server as kf_create_certificate_store_server
import \
    keyfactor_v_1_client.api.certificate_store.certificate_store_add_certificate as kf_add_certificate
import \
    keyfactor_v_1_client.api.certificate_store.certificate_store_schedule_for_reenrollment as kf_schedule_for_reenrollment
import \
    keyfactor_v_1_client.api.certificate_store.certificate_store_remove_certificate as kf_remove_certificate
import \
    keyfactor_v_1_client.api.certificate_store.certificate_store_delete_certificate_stores as kf_delete_certificate_stores
import \
    keyfactor_v_1_client.api.monitoring.monitoring_edit_revocation_monitoring as kf_edit_revocation_monitoring
import \
    keyfactor_v_1_client.api.monitoring.monitoring_add_revocation_monitoring as kf_add_revocation_monitoring
import \
    keyfactor_v_1_client.api.monitoring.monitoring_delete_revocation_monitoring as kf_delete_revocation_monitoring
import \
    keyfactor_v_1_client.api.monitoring.monitoring_get_revocation_monitoring_endpoints as kf_get_revocation_monitoring_endpoints
import \
    keyfactor_v_1_client.api.monitoring.monitoring_get_revocation_monitoring as kf_get_revocation_monitoring
import keyfactor_v_1_client.api.monitoring.monitoring_resolve_ocsp as kf_resolve_ocsp
import \
    keyfactor_v_1_client.api.monitoring.monitoring_test_revocation_monitoring_alert as kf_test_revocation_monitoring_alert
import \
    keyfactor_v_1_client.api.monitoring.monitoring_test_all_revocation_monitoring_alert as kf_test_all_revocation_monitoring_alert
import keyfactor_v_1_client.api.server.server_add_access as kf_add_access
import keyfactor_v_1_client.api.server.server_create_server as kf_create_server
import keyfactor_v_1_client.api.server.server_get as kf_get
import keyfactor_v_1_client.api.server.server_query_servers as kf_query_servers
import keyfactor_v_1_client.api.server.server_remove_access as kf_remove_access
import keyfactor_v_1_client.api.server.server_delete as kf_delete
import keyfactor_v_1_client.api.server.server_get_access as kf_get_access
import keyfactor_v_1_client.api.server.server_update_server as kf_update_server
import keyfactor_v_1_client.api.status.status_get_endpoints as kf_get_endpoints
import keyfactor_v_1_client.api.agent_pool.agent_pool_get_agent_pools as kf_get_agent_pools
import \
    keyfactor_v_1_client.api.agent_pool.agent_pool_get_default_agent_pool_agents as kf_get_default_agent_pool_agents
import \
    keyfactor_v_1_client.api.agent_pool.agent_pool_get_agent_pool_by_id as kf_get_agent_pool_by_id
import keyfactor_v_1_client.api.agent_pool.agent_pool_create_agent_pool as kf_create_agent_pool
import keyfactor_v_1_client.api.agent_pool.agent_pool_delete_agent_pool as kf_delete_agent_pool
import keyfactor_v_1_client.api.agent_pool.agent_pool_update_agent_pool as kf_update_agent_pool
import keyfactor_v_1_client.api.enrollment.enrollment_renew as kf_renew
import \
    keyfactor_v_1_client.api.enrollment.enrollment_install_pfx_to_cert_store as kf_install_pfx_to_cert_store
import \
    keyfactor_v_1_client.api.enrollment.enrollment_add_to_existing_cert_stores as kf_add_to_existing_cert_stores
import keyfactor_v_1_client.api.enrollment.enrollment_get_my_pfx_context as kf_get_my_pfx_context
import \
    keyfactor_v_1_client.api.enrollment.enrollment_available_renewal_id as kf_available_renewal_id
import \
    keyfactor_v_1_client.api.enrollment.enrollment_get_template_enrollment_settings as kf_get_template_enrollment_settings
import keyfactor_v_1_client.api.enrollment.enrollment_get_my_csr_context as kf_get_my_csr_context
import keyfactor_v_1_client.api.enrollment.enrollment_post_csr_enroll as kf_post_csr_enroll
import keyfactor_v_1_client.api.enrollment.enrollment_post_parsed_csr as kf_post_parsed_csr
import keyfactor_v_1_client.api.enrollment.enrollment_post_pfx_enroll as kf_post_pfx_enroll
import \
    keyfactor_v_1_client.api.enrollment.enrollment_available_renewal_thumbprint as kf_available_renewal_thumbprint
import keyfactor_v_1_client.api.certificate.certificate_revoke as kf_revoke
import keyfactor_v_1_client.api.certificate.certificate_update_metadata as kf_update_metadata
import \
    keyfactor_v_1_client.api.certificate.certificate_delete_certificates as kf_delete_certificates
import \
    keyfactor_v_1_client.api.certificate.certificate_get_certificate_security as kf_get_certificate_security
import \
    keyfactor_v_1_client.api.certificate.certificate_download_certificate_async as kf_download_certificate_async
import \
    keyfactor_v_1_client.api.certificate.certificate_validate_certificate as kf_validate_certificate
import \
    keyfactor_v_1_client.api.certificate.certificate_certificate_history as kf_certificate_history
import \
    keyfactor_v_1_client.api.certificate.certificate_update_all_metadata as kf_update_all_metadata
import \
    keyfactor_v_1_client.api.certificate.certificate_recover_certificate_async as kf_recover_certificate_async
import keyfactor_v_1_client.api.certificate.certificate_revoke_all as kf_revoke_all
import \
    keyfactor_v_1_client.api.certificate.certificate_delete_private_keys_0 as kf_delete_private_keys_0
import \
    keyfactor_v_1_client.api.certificate.certificate_delete_private_keys_1 as kf_delete_private_keys_1
import keyfactor_v_1_client.api.certificate.certificate_query_certificates as kf_query_certificates
import keyfactor_v_1_client.api.certificate.certificate_delete_certificate as kf_delete_certificate
import keyfactor_v_1_client.api.certificate.certificate_compare_metadata as kf_compare_metadata
import \
    keyfactor_v_1_client.api.certificate.certificate_post_import_certificate as kf_post_import_certificate
import keyfactor_v_1_client.api.certificate.certificate_get_certificate as kf_get_certificate
import keyfactor_v_1_client.api.certificate.certificate_delete_by_query as kf_delete_by_query
import keyfactor_v_1_client.api.certificate.certificate_analyze_cert as kf_analyze_cert
import keyfactor_v_1_client.api.certificate.certificate_identity_audit as kf_identity_audit
import \
    keyfactor_v_1_client.api.certificate.certificate_get_certificate_locations as kf_get_certificate_locations
import keyfactor_v_1_client.api.template.template_get_templates as kf_get_templates
import \
    keyfactor_v_1_client.api.template.template_get_valid_subject_parts as kf_get_valid_subject_parts
import \
    keyfactor_v_1_client.api.template.template_update_global_settings as kf_update_global_settings
import keyfactor_v_1_client.api.template.template_update_template as kf_update_template
import keyfactor_v_1_client.api.template.template_get_global_settings as kf_get_global_settings
import keyfactor_v_1_client.api.template.template_get_template as kf_get_template
import keyfactor_v_1_client.api.template.template_import as kf_import
import \
    keyfactor_v_1_client.api.certificate_collection.certificate_collection_update_collection as kf_update_collection
import \
    keyfactor_v_1_client.api.certificate_collection.certificate_collection_get_collection_0 as kf_get_collection_0
import \
    keyfactor_v_1_client.api.certificate_collection.certificate_collection_set_collection_permissions as kf_set_collection_permissions
import \
    keyfactor_v_1_client.api.certificate_collection.certificate_collection_create_collection as kf_create_collection
import \
    keyfactor_v_1_client.api.certificate_collection.certificate_collection_copy_from_existing_collection as kf_copy_from_existing_collection
import \
    keyfactor_v_1_client.api.certificate_collection.certificate_collection_get_collections as kf_get_collections
import \
    keyfactor_v_1_client.api.certificate_collection.certificate_collection_get_collection_1 as kf_get_collection_1
import \
    keyfactor_v_1_client.api.security_roles.security_roles_get_identities_with_role as kf_get_identities_with_role
import \
    keyfactor_v_1_client.api.security_roles.security_roles_delete_security_role as kf_delete_security_role
import \
    keyfactor_v_1_client.api.security_roles.security_roles_update_identities_with_role as kf_update_identities_with_role
import keyfactor_v_1_client.api.server_group.server_group_add_access as kf_add_access
import keyfactor_v_1_client.api.server_group.server_group_get_group as kf_get_group
import keyfactor_v_1_client.api.server_group.server_group_get_group_by_name as kf_get_group_by_name
import \
    keyfactor_v_1_client.api.server_group.server_group_update_server_group as kf_update_server_group
import keyfactor_v_1_client.api.server_group.server_group_remove_access as kf_remove_access
import keyfactor_v_1_client.api.server_group.server_group_delete as kf_delete
import keyfactor_v_1_client.api.server_group.server_group_get_access as kf_get_access
import \
    keyfactor_v_1_client.api.server_group.server_group_create_server_group as kf_create_server_group
import \
    keyfactor_v_1_client.api.server_group.server_group_query_server_groups as kf_query_server_groups
import keyfactor_v_1_client.api.reports.reports_update_report_schedule as kf_update_report_schedule
import keyfactor_v_1_client.api.reports.reports_delete_report_schedule as kf_delete_report_schedule
import \
    keyfactor_v_1_client.api.reports.reports_update_report_parameters as kf_update_report_parameters
import keyfactor_v_1_client.api.reports.reports_update_custom_report as kf_update_custom_report
import keyfactor_v_1_client.api.reports.reports_query_reports as kf_query_reports
import keyfactor_v_1_client.api.reports.reports_query_custom_reports as kf_query_custom_reports
import keyfactor_v_1_client.api.reports.reports_get_report_parameters as kf_get_report_parameters
import keyfactor_v_1_client.api.reports.reports_get_report_schedule as kf_get_report_schedule
import keyfactor_v_1_client.api.reports.reports_update_report as kf_update_report
import keyfactor_v_1_client.api.reports.reports_get_report_schedules as kf_get_report_schedules
import keyfactor_v_1_client.api.reports.reports_get_report as kf_get_report
import keyfactor_v_1_client.api.reports.reports_get_custom_report as kf_get_custom_report
import keyfactor_v_1_client.api.reports.reports_create_report_schedule as kf_create_report_schedule
import keyfactor_v_1_client.api.reports.reports_delete_report as kf_delete_report
import keyfactor_v_1_client.api.reports.reports_create_custom_report as kf_create_custom_report
import \
    keyfactor_v_1_client.api.certificate_store_container.certificate_store_container_get_all_certificate_store_containers as kf_get_all_certificate_store_containers
import \
    keyfactor_v_1_client.api.certificate_store_container.certificate_store_container_delete_certificate_store_containers as kf_delete_certificate_store_containers
import keyfactor_v_1_client.api.user.user_delete_user as kf_delete_user
import keyfactor_v_1_client.api.user.user_query_users as kf_query_users
import keyfactor_v_1_client.api.user.user_get_user as kf_get_user
import keyfactor_v_1_client.api.user.user_create_user as kf_create_user
import keyfactor_v_1_client.api.user.user_update_user as kf_update_user
import keyfactor_v_1_client.api.user.user_user_access as kf_user_access
import \
    keyfactor_v_1_client.api.pam_provider.pam_provider_delete_pam_provider as kf_delete_pam_provider
import \
    keyfactor_v_1_client.api.pam_provider.pam_provider_create_pam_provider_type as kf_create_pam_provider_type
import \
    keyfactor_v_1_client.api.metadata_field.metadata_field_get_metadata_field_in_use as kf_get_metadata_field_in_use
import \
    keyfactor_v_1_client.api.metadata_field.metadata_field_delete_metadata_fields as kf_delete_metadata_fields
import \
    keyfactor_v_1_client.api.metadata_field.metadata_field_get_metadata_field_0 as kf_get_metadata_field_0
import \
    keyfactor_v_1_client.api.metadata_field.metadata_field_create_metadata_field as kf_create_metadata_field
import \
    keyfactor_v_1_client.api.metadata_field.metadata_field_get_metadata_field_1 as kf_get_metadata_field_1
import \
    keyfactor_v_1_client.api.metadata_field.metadata_field_get_all_metadata_fields as kf_get_all_metadata_fields
import \
    keyfactor_v_1_client.api.metadata_field.metadata_field_update_metadata_field as kf_update_metadata_field
import \
    keyfactor_v_1_client.api.metadata_field.metadata_field_delete_metadata_field as kf_delete_metadata_field
import \
    keyfactor_v_1_client.api.security.security_delete_security_identity as kf_delete_security_identity
import keyfactor_v_1_client.api.security.security_identity_permissions as kf_identity_permissions
import keyfactor_v_1_client.api.security.security_lookup_identity as kf_lookup_identity
import keyfactor_v_1_client.api.workflow.workflow_deny_pending_requests as kf_deny_pending_requests
import keyfactor_v_1_client.api.workflow.workflow_get as kf_get
import \
    keyfactor_v_1_client.api.workflow.workflow_approve_pending_requests as kf_approve_pending_requests
import \
    keyfactor_v_1_client.api.workflow.workflow_get_certificate_request_details as kf_get_certificate_request_details
import keyfactor_v_1_client.api.workflow.workflow_get_denied as kf_get_denied
import keyfactor_v_1_client.api.denied_alert.denied_alert_get_denied_alert as kf_get_denied_alert
import \
    keyfactor_v_1_client.api.denied_alert.denied_alert_delete_denied_alert as kf_delete_denied_alert
import keyfactor_v_1_client.api.denied_alert.denied_alert_get_denied_alerts as kf_get_denied_alerts
import keyfactor_v_1_client.api.denied_alert.denied_alert_edit_denied_alert as kf_edit_denied_alert
import keyfactor_v_1_client.api.denied_alert.denied_alert_add_denied_alert as kf_add_denied_alert
import keyfactor_v_1_client.api.issued_alert.issued_alert_get_issued_alerts as kf_get_issued_alerts
import keyfactor_v_1_client.api.issued_alert.issued_alert_add_issued_alert as kf_add_issued_alert
import keyfactor_v_1_client.api.issued_alert.issued_alert_edit_issued_alert as kf_edit_issued_alert
import keyfactor_v_1_client.api.issued_alert.issued_alert_get_schedule as kf_get_schedule
import keyfactor_v_1_client.api.issued_alert.issued_alert_edit_schedule as kf_edit_schedule
import keyfactor_v_1_client.api.issued_alert.issued_alert_get_issued_alert as kf_get_issued_alert
import \
    keyfactor_v_1_client.api.issued_alert.issued_alert_delete_issued_alert as kf_delete_issued_alert
import \
    keyfactor_v_1_client.api.agent_blueprint.agent_blueprint_get_agent_blueprints as kf_get_agent_blueprints
import \
    keyfactor_v_1_client.api.agent_blueprint.agent_blueprint_apply_blueprint as kf_apply_blueprint
import \
    keyfactor_v_1_client.api.agent_blueprint.agent_blueprint_delete_blueprint as kf_delete_blueprint
import \
    keyfactor_v_1_client.api.agent_blueprint.agent_blueprint_get_blueprint_jobs as kf_get_blueprint_jobs
import \
    keyfactor_v_1_client.api.agent_blueprint.agent_blueprint_get_agent_blueprint as kf_get_agent_blueprint
import \
    keyfactor_v_1_client.api.agent_blueprint.agent_blueprint_generate_blueprint as kf_generate_blueprint
import \
    keyfactor_v_1_client.api.agent_blueprint.agent_blueprint_get_blueprint_stores as kf_get_blueprint_stores
import keyfactor_v_1_client.api.ssl.ssl_set_network_ranges as kf_set_network_ranges
import keyfactor_v_1_client.api.ssl.ssl_network_scan_parts as kf_network_scan_parts
import keyfactor_v_1_client.api.ssl.ssl_validate_network_ranges as kf_validate_network_ranges
import keyfactor_v_1_client.api.ssl.ssl_update_network as kf_update_network
import keyfactor_v_1_client.api.ssl.ssl_results as kf_results
import keyfactor_v_1_client.api.ssl.ssl_add_network_ranges as kf_add_network_ranges
import keyfactor_v_1_client.api.ssl.ssl_endpoint_history as kf_endpoint_history
import keyfactor_v_1_client.api.ssl.ssl_get_network as kf_get_network
import keyfactor_v_1_client.api.ssl.ssl_get_networks as kf_get_networks
import keyfactor_v_1_client.api.ssl.ssl_create_network as kf_create_network
import \
    keyfactor_v_1_client.api.ssl.ssl_get_network_ranges_for_network as kf_get_network_ranges_for_network
import keyfactor_v_1_client.api.ssl.ssl_monitoring_status as kf_monitoring_status
import keyfactor_v_1_client.api.ssl.ssl_scan_part as kf_scan_part
import keyfactor_v_1_client.api.ssl.ssl_monitor_all as kf_monitor_all
import keyfactor_v_1_client.api.ssl.ssl_review_all as kf_review_all
import keyfactor_v_1_client.api.ssl.ssl_remove_network as kf_remove_network
import keyfactor_v_1_client.api.ssl.ssl_remove_all_network_ranges as kf_remove_all_network_ranges
import keyfactor_v_1_client.api.ssl.ssl_immediate_ssl_scan as kf_immediate_ssl_scan
import keyfactor_v_1_client.api.ssl.ssl_endpoint as kf_endpoint
import keyfactor_v_1_client.api.ssl.ssl_reviewed_status as kf_reviewed_status
import \
    keyfactor_v_1_client.api.custom_job_type.custom_job_type_update_job_type as kf_update_job_type
import \
    keyfactor_v_1_client.api.custom_job_type.custom_job_type_delete_job_type as kf_delete_job_type
import \
    keyfactor_v_1_client.api.custom_job_type.custom_job_type_get_job_type_by_id as kf_get_job_type_by_id
import keyfactor_v_1_client.api.custom_job_type.custom_job_type_get_job_types as kf_get_job_types
import \
    keyfactor_v_1_client.api.custom_job_type.custom_job_type_create_job_type as kf_create_job_type
import keyfactor_v_1_client.api.agent.agent_get_agents as kf_get_agents
import keyfactor_v_1_client.api.agent.agent_reset_1 as kf_reset_1
import keyfactor_v_1_client.api.agent.agent_approve as kf_approve
import \
    keyfactor_v_1_client.api.agent.agent_set_auth_certificate_reenrollment as kf_set_auth_certificate_reenrollment
import keyfactor_v_1_client.api.agent.agent_disapprove as kf_disapprove
import keyfactor_v_1_client.api.agent.agent_fetch_logs as kf_fetch_logs
import keyfactor_v_1_client.api.agent.agent_get_agent_detail as kf_get_agent_detail
import keyfactor_v_1_client.api.agent.agent_reset_0 as kf_reset_0
import \
    keyfactor_v_1_client.api.pending_alert.pending_alert_edit_pending_alert as kf_edit_pending_alert
import \
    keyfactor_v_1_client.api.pending_alert.pending_alert_test_all_pending_alert as kf_test_all_pending_alert
import \
    keyfactor_v_1_client.api.pending_alert.pending_alert_test_pending_alert as kf_test_pending_alert
import keyfactor_v_1_client.api.pending_alert.pending_alert_get_schedule as kf_get_schedule
import \
    keyfactor_v_1_client.api.pending_alert.pending_alert_delete_pending_alert as kf_delete_pending_alert
import \
    keyfactor_v_1_client.api.pending_alert.pending_alert_get_pending_alerts as kf_get_pending_alerts
import \
    keyfactor_v_1_client.api.pending_alert.pending_alert_get_pending_alert as kf_get_pending_alert
import \
    keyfactor_v_1_client.api.pending_alert.pending_alert_add_pending_alert as kf_add_pending_alert
import keyfactor_v_1_client.api.pending_alert.pending_alert_edit_schedule as kf_edit_schedule
import keyfactor_v_1_client.api.license_.license_get_current_license as kf_et_current_license
import \
    keyfactor_v_1_client.api.mac_enrollment.mac_enrollment_edit_mac_enrollment as kf_edit_mac_enrollment
import keyfactor_v_1_client.api.mac_enrollment.mac_enrollment_mac_enrollment as kf_mac_enrollment
import \
    keyfactor_v_1_client.api.workflow_definition.workflow_definition_publish_definition as kf_publish_definition
import keyfactor_v_1_client.api.workflow_definition.workflow_definition_query as kf_query
import keyfactor_v_1_client.api.workflow_definition.workflow_definition_get as kf_get
import \
    keyfactor_v_1_client.api.workflow_definition.workflow_definition_configure_definition_steps as kf_configure_definition_steps
import \
    keyfactor_v_1_client.api.workflow_definition.workflow_definition_query_workflow_types as kf_query_workflow_types
import \
    keyfactor_v_1_client.api.workflow_definition.workflow_definition_update_existing_definition as kf_update_existing_definition
import \
    keyfactor_v_1_client.api.workflow_definition.workflow_definition_get_step_schema as kf_get_step_schema
import \
    keyfactor_v_1_client.api.workflow_definition.workflow_definition_query_available_steps as kf_query_available_steps
import \
    keyfactor_v_1_client.api.workflow_definition.workflow_definition_create_new_definition as kf_create_new_definition
import keyfactor_v_1_client.api.workflow_definition.workflow_definition_delete as kf_delete
import \
    keyfactor_v_1_client.api.key_rotation_alert.key_rotation_alert_add_key_rotation_alert as kf_add_key_rotation_alert
import \
    keyfactor_v_1_client.api.key_rotation_alert.key_rotation_alert_test_all_key_rotation_alert as kf_test_all_key_rotation_alert
import \
    keyfactor_v_1_client.api.key_rotation_alert.key_rotation_alert_get_key_rotation_alerts as kf_get_key_rotation_alerts
import \
    keyfactor_v_1_client.api.key_rotation_alert.key_rotation_alert_get_schedule as kf_get_schedule
import \
    keyfactor_v_1_client.api.key_rotation_alert.key_rotation_alert_delete_key_rotation_alert as kf_delete_key_rotation_alert
import \
    keyfactor_v_1_client.api.key_rotation_alert.key_rotation_alert_edit_schedule as kf_edit_schedule
import \
    keyfactor_v_1_client.api.key_rotation_alert.key_rotation_alert_get_key_rotation_alert as kf_get_key_rotation_alert
import \
    keyfactor_v_1_client.api.key_rotation_alert.key_rotation_alert_test_key_rotation_alert as kf_test_key_rotation_alert
import \
    keyfactor_v_1_client.api.key_rotation_alert.key_rotation_alert_edit_key_rotation_alert as kf_edit_key_rotation_alert
import keyfactor_v_1_client.api.key.key_get_unmanaged_keys as kf_get_unmanaged_keys
import keyfactor_v_1_client.api.key.key_get_unmanaged_key as kf_get_unmanaged_key
import keyfactor_v_1_client.api.key.key_update as kf_update
import keyfactor_v_1_client.api.key.key_delete_unmanaged_keys as kf_delete_unmanaged_keys
import keyfactor_v_1_client.api.key.key_generate_key as kf_generate_key
import keyfactor_v_1_client.api.key.key_delete_unmanaged_key as kf_delete_unmanaged_key
import keyfactor_v_1_client.api.key.key_get_my_key as kf_get_my_key
import keyfactor_v_1_client.api.smtp.smtp_smtp as kf_smtp
import keyfactor_v_1_client.api.smtp.smtp_update_smtp as kf_update_smtp
import keyfactor_v_1_client.api.smtp.smtp_test_smtp as kf_test_smtp
import \
    keyfactor_v_1_client.api.certificate_store_type.certificate_store_type_get_certificate_store_type_0 as kf_get_certificate_store_type_0
import \
    keyfactor_v_1_client.api.certificate_store_type.certificate_store_type_delete_certificate_store_types as kf_delete_certificate_store_types
import \
    keyfactor_v_1_client.api.certificate_store_type.certificate_store_type_delete_certificate_store_type as kf_delete_certificate_store_type
import \
    keyfactor_v_1_client.api.certificate_store_type.certificate_store_type_update_certificate_store_type as kf_update_certificate_store_type
import \
    keyfactor_v_1_client.api.certificate_store_type.certificate_store_type_get_certificate_store_type_1 as kf_get_certificate_store_type_1
import \
    keyfactor_v_1_client.api.certificate_store_type.certificate_store_type_create_certificate_store_type as kf_create_certificate_store_type
import \
    keyfactor_v_1_client.api.certificate_store_type.certificate_store_type_get_types as kf_get_types
import \
    keyfactor_v_1_client.models.keyfactor_api_models_monitoring_revocation_monitoring_alert_test_response as kf_keyfactor_api_models_monitoring_revocation_monitoring_alert_test_response
import \
    keyfactor_v_1_client.models.models_certificate_store_create_server_request as kf_models_certificate_store_create_server_request
import \
    keyfactor_v_1_client.models.models_template_metadata_field as kf_models_template_metadata_field
import \
    keyfactor_v_1_client.models.keyfactor_api_models_security_roles_identities_security_roles_global_permission_response as kf_keyfactor_api_models_security_roles_identities_security_roles_global_permission_response
import \
    keyfactor_v_1_client.models.models_certificate_stores_certificate_store_update_request as kf_models_certificate_stores_certificate_store_update_request
import \
    keyfactor_v_1_client.models.models_query_models_workflow_workflow_step_schema_query as kf_models_query_models_workflow_workflow_step_schema_query
import \
    keyfactor_v_1_client.models.models_enrollment_available_renewal as kf_models_enrollment_available_renewal
import \
    keyfactor_v_1_client.models.models_template_collection_retrieval_response_extended_key_usage_model as kf_models_template_collection_retrieval_response_extended_key_usage_model
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_definition_step_request_outputs as kf_keyfactor_api_models_workflows_definition_step_request_outputs
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_definition_update_request as kf_keyfactor_api_models_workflows_definition_update_request
import \
    keyfactor_v_1_client.models.models_certificate_location_specifier_job_fields_additional_property as kf_models_certificate_location_specifier_job_fields_additional_property
import \
    keyfactor_v_1_client.models.models_query_models_paged_agent_blueprint_stores_query_sort_ascending as kf_models_query_models_paged_agent_blueprint_stores_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_certificate_store_entry as kf_models_certificate_store_entry
import \
    keyfactor_v_1_client.models.keyfactor_api_models_ssl_quiet_hour_response_start_day as kf_keyfactor_api_models_ssl_quiet_hour_response_start_day
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_instance_response_current_state_data_additional_property as kf_keyfactor_api_models_workflows_instance_response_current_state_data_additional_property
import \
    keyfactor_v_1_client.models.models_ssh_keys_key_generation_request as kf_models_ssh_keys_key_generation_request
import \
    keyfactor_v_1_client.models.template_get_templates_sq_sort_ascending as kf_template_get_templates_sq_sort_ascending
import \
    keyfactor_v_1_client.models.custom_job_type_get_job_types_pq_sort_ascending as kf_custom_job_type_get_job_types_pq_sort_ascending
import \
    keyfactor_v_1_client.models.models_metadata_update_request as kf_models_metadata_update_request
import \
    keyfactor_v_1_client.models.models_query_models_paged_certificate_store_inventory_query_sort_ascending as kf_models_query_models_paged_certificate_store_inventory_query_sort_ascending
import \
    keyfactor_v_1_client.models.audit_log_get_audit_logs_pq_sort_ascending as kf_audit_log_get_audit_logs_pq_sort_ascending
import \
    keyfactor_v_1_client.models.models_ssh_server_groups_server_group_response as kf_models_ssh_server_groups_server_group_response
import \
    keyfactor_v_1_client.models.models_orchestrator_jobs_schedule_job_request_job_fields as kf_models_orchestrator_jobs_schedule_job_request_job_fields
import keyfactor_v_1_client.models.models_template_regex as kf_models_template_regex
import \
    keyfactor_v_1_client.models.keyfactor_api_models_enrollment_management_store_type_request as kf_keyfactor_api_models_enrollment_management_store_type_request
import \
    keyfactor_v_1_client.models.models_query_models_paged_custom_report_query as kf_models_query_models_paged_custom_report_query
import \
    keyfactor_v_1_client.models.models_ssh_logons_logon_response as kf_models_ssh_logons_logon_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_instance_response_status as kf_keyfactor_api_models_workflows_instance_response_status
import \
    keyfactor_v_1_client.models.models_query_models_paged_agent_job_query as kf_models_query_models_paged_agent_job_query
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_expiration_expiration_alert_test_response_alert_build_result as kf_keyfactor_api_models_alerts_expiration_expiration_alert_test_response_alert_build_result
import \
    keyfactor_v_1_client.models.models_certificate_store_entry_job_fields_additional_property as kf_models_certificate_store_entry_job_fields_additional_property
import \
    keyfactor_v_1_client.models.certificate_query_certificates_pq_sort_ascending as kf_certificate_query_certificates_pq_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_auditing_querying_audit_log_entry as kf_keyfactor_auditing_querying_audit_log_entry
import \
    keyfactor_v_1_client.models.models_metadata_field_type_model_data_type as kf_models_metadata_field_type_model_data_type
import \
    keyfactor_v_1_client.models.keyfactor_api_models_ssl_quiet_hour_response_end_day as kf_keyfactor_api_models_ssl_quiet_hour_response_end_day
import \
    keyfactor_v_1_client.models.models_ssl_network_ranges_request as kf_models_ssl_network_ranges_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificates_analyze_certificate_request as kf_keyfactor_api_models_certificates_analyze_certificate_request
import \
    keyfactor_v_1_client.models.models_query_models_paged_agent_blueprint_query_sort_ascending as kf_models_query_models_paged_agent_blueprint_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_available_step_response as kf_keyfactor_api_models_workflows_available_step_response
import keyfactor_v_1_client.models.models_certificate_details as kf_models_certificate_details
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_alert_certificate_query_alert_certificate_query_response as kf_keyfactor_api_models_alerts_alert_certificate_query_alert_certificate_query_response
import \
    keyfactor_v_1_client.models.models_ssh_servers_server_response as kf_models_ssh_servers_server_response
import \
    keyfactor_v_1_client.models.models_orchestrator_jobs_job_type_field_request_type as kf_models_orchestrator_jobs_job_type_field_request_type
import \
    keyfactor_v_1_client.models.keyfactor_api_models_ssl_create_network_request as kf_keyfactor_api_models_ssl_create_network_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_monitoring_email_request as kf_keyfactor_api_models_monitoring_email_request
import \
    keyfactor_v_1_client.models.models_certificate_download_response as kf_models_certificate_download_response
import \
    keyfactor_v_1_client.models.models_query_models_paged_ssh_logon_query_sort_ascending as kf_models_query_models_paged_ssh_logon_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_ssl_network_response_discover_status as kf_keyfactor_api_models_ssl_network_response_discover_status
import \
    keyfactor_v_1_client.models.models_ssl_endpoint_history_response_status as kf_models_ssl_endpoint_history_response_status
import \
    keyfactor_v_1_client.models.models_query_models_paged_denied_alert_query as kf_models_query_models_paged_denied_alert_query
import \
    keyfactor_v_1_client.models.models_certificate_retrieval_response_cert_state as kf_models_certificate_retrieval_response_cert_state
import \
    keyfactor_v_1_client.models.keyfactor_api_models_event_handler_registered_event_handler_request as kf_keyfactor_api_models_event_handler_registered_event_handler_request
import \
    keyfactor_v_1_client.models.models_template_collection_retrieval_response_template_enrollment_field_model_data_type as kf_models_template_collection_retrieval_response_template_enrollment_field_model_data_type
import \
    keyfactor_v_1_client.models.models_metadata_field_type_model as kf_models_metadata_field_type_model
import \
    keyfactor_v_1_client.models.models_query_models_paged_expiration_alert_query_sort_ascending as kf_models_query_models_paged_expiration_alert_query_sort_ascending
import \
    keyfactor_v_1_client.models.user_query_users_pq_sort_ascending as kf_user_query_users_pq_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_templates_global_template_settings_request as kf_keyfactor_api_models_templates_global_template_settings_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_key_rotation_key_rotation_alert_test_response as kf_keyfactor_api_models_alerts_key_rotation_key_rotation_alert_test_response
import \
    keyfactor_v_1_client.models.models_ssl_immediate_ssl_scan_request as kf_models_ssl_immediate_ssl_scan_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_key_rotation_key_rotation_alert_test_request as kf_keyfactor_api_models_alerts_key_rotation_key_rotation_alert_test_request
import \
    keyfactor_v_1_client.models.models_query_models_workflow_workflow_type_query as kf_models_query_models_workflow_workflow_type_query
import \
    keyfactor_v_1_client.models.models_cert_store_new_password_request as kf_models_cert_store_new_password_request
import \
    keyfactor_v_1_client.models.keyfactor_common_scheduling_models_weekly_model as kf_keyfactor_common_scheduling_models_weekly_model
import \
    keyfactor_v_1_client.models.models_template_retrieval_response_template_metadata_field_model as kf_models_template_retrieval_response_template_metadata_field_model
import \
    keyfactor_v_1_client.models.models_enrollment_renewal_request as kf_models_enrollment_renewal_request
import \
    keyfactor_v_1_client.models.models_certificate_retrieval_response_location_count_model as kf_models_certificate_retrieval_response_location_count_model
import \
    keyfactor_v_1_client.models.models_security_security_roles_security_role_response_base as kf_models_security_security_roles_security_role_response_base
import \
    keyfactor_v_1_client.models.models_query_models_workflow_workflow_type_query_sort_ascending as kf_models_query_models_workflow_workflow_type_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_workflow_type_query_response as kf_keyfactor_api_models_workflows_workflow_type_query_response
import \
    keyfactor_v_1_client.models.models_ssh_logons_logon_creation_request as kf_models_ssh_logons_logon_creation_request
import \
    keyfactor_v_1_client.models.models_template_update_request_key_retention as kf_models_template_update_request_key_retention
import \
    keyfactor_v_1_client.models.keyfactor_api_models_metadata_field_metadata_field_update_request_enrollment as kf_keyfactor_api_models_metadata_field_metadata_field_update_request_enrollment
import \
    keyfactor_v_1_client.models.models_metadata_field_type_model_enrollment as kf_models_metadata_field_type_model_enrollment
import keyfactor_v_1_client.models.models_ssl_ssl_scan_result as kf_models_ssl_ssl_scan_result
import \
    keyfactor_v_1_client.models.models_certificate_store_types_certificate_store_type_entry_parameter as kf_models_certificate_store_types_certificate_store_type_entry_parameter
import \
    keyfactor_v_1_client.models.models_query_models_paged_scan_job_parts_query_sort_ascending as kf_models_query_models_paged_scan_job_parts_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_monitoring_revocation_monitoring_definition_response as kf_keyfactor_api_models_monitoring_revocation_monitoring_definition_response
import keyfactor_v_1_client.models.models_ssl_network_definition as kf_models_ssl_network_definition
import \
    keyfactor_v_1_client.models.models_query_models_paged_metadata_field_query_sort_ascending as kf_models_query_models_paged_metadata_field_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_query_models_paged_certificate_store_query_sort_ascending as kf_models_query_models_paged_certificate_store_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_pam_provider_type_parameter_response as kf_keyfactor_api_pam_provider_type_parameter_response
import \
    keyfactor_v_1_client.models.models_enrollment_management_store_type as kf_models_enrollment_management_store_type
import \
    keyfactor_v_1_client.models.keyfactor_api_models_monitoring_revocation_monitoring_alert_test_request as kf_keyfactor_api_models_monitoring_revocation_monitoring_alert_test_request
import \
    keyfactor_v_1_client.models.certificate_collection_get_collections_pq_sort_ascending as kf_certificate_collection_get_collections_pq_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_key_rotation_key_rotation_alert_creation_request as kf_keyfactor_api_models_alerts_key_rotation_key_rotation_alert_creation_request
import \
    keyfactor_v_1_client.models.models_query_models_paged_template_query_sort_ascending as kf_models_query_models_paged_template_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_query_models_paged_certificate_store_server_query as kf_models_query_models_paged_certificate_store_server_query
import \
    keyfactor_v_1_client.models.keyfactor_api_models_metadata_field_metadata_field_create_request as kf_keyfactor_api_models_metadata_field_metadata_field_create_request
import \
    keyfactor_v_1_client.models.models_ssh_servers_server_creation_request as kf_models_ssh_servers_server_creation_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_stores_types_certificate_store_type_creation_request_custom_alias_allowed as kf_keyfactor_api_models_certificate_stores_types_certificate_store_type_creation_request_custom_alias_allowed
import \
    keyfactor_v_1_client.models.models_security_identities_security_identity_identifier as kf_models_security_identities_security_identity_identifier
import \
    keyfactor_v_1_client.models.agent_pool_get_agent_pools_pq_sort_ascending as kf_agent_pool_get_agent_pools_pq_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_definition_step_response_configuration_parameters_additional_property as kf_keyfactor_api_models_workflows_definition_step_response_configuration_parameters_additional_property
import \
    keyfactor_v_1_client.models.models_enrollment_pfx_enrollment_response_metadata as kf_models_enrollment_pfx_enrollment_response_metadata
import \
    keyfactor_v_1_client.models.models_ssh_servers_server_update_request as kf_models_ssh_servers_server_update_request
import \
    keyfactor_v_1_client.models.models_report_parameters_request as kf_models_report_parameters_request
import \
    keyfactor_v_1_client.models.models_query_models_paged_pending_csr_query_sort_ascending as kf_models_query_models_paged_pending_csr_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_certificate_import_request_model as kf_models_certificate_import_request_model
import \
    keyfactor_v_1_client.models.models_security_identities_permission_roles_pair_response as kf_models_security_identities_permission_roles_pair_response
import \
    keyfactor_v_1_client.models.models_query_models_paged_agent_blueprint_stores_query as kf_models_query_models_paged_agent_blueprint_stores_query
import \
    keyfactor_v_1_client.models.keyfactor_common_scheduling_models_interval_model as kf_keyfactor_common_scheduling_models_interval_model
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_expiration_expiration_alert_response as kf_keyfactor_api_models_alerts_expiration_expiration_alert_response
import \
    keyfactor_v_1_client.models.models_cert_store_locations_certificate_locations_group as kf_models_cert_store_locations_certificate_locations_group
import \
    keyfactor_v_1_client.models.models_certificate_query_duplication_field as kf_models_certificate_query_duplication_field
import \
    keyfactor_v_1_client.models.models_ssl_endpoint_history_response_certificate_model as kf_models_ssl_endpoint_history_response_certificate_model
import \
    keyfactor_v_1_client.models.keyfactor_api_models_monitoring_revocation_monitoring_creation_request as kf_keyfactor_api_models_monitoring_revocation_monitoring_creation_request
import \
    keyfactor_v_1_client.models.models_enrollment_csr_enrollment_request_metadata as kf_models_enrollment_csr_enrollment_request_metadata
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_pending_pending_alert_update_request as kf_keyfactor_api_models_alerts_pending_pending_alert_update_request
import \
    keyfactor_v_1_client.models.models_pki_certificate_operation as kf_models_pki_certificate_operation
import \
    keyfactor_v_1_client.models.models_certificate_location_specifier_job_fields as kf_models_certificate_location_specifier_job_fields
import \
    keyfactor_v_1_client.models.models_certificate_import_response_model_job_status as kf_models_certificate_import_response_model_job_status
import \
    keyfactor_v_1_client.models.models_workflow_certificate_request_details_model_state as kf_models_workflow_certificate_request_details_model_state
import \
    keyfactor_v_1_client.models.models_enrollment_csr_generation_request_sa_ns as kf_models_enrollment_csr_generation_request_sa_ns
import \
    keyfactor_v_1_client.models.agent_pool_get_default_agent_pool_agents_pq_sort_ascending as kf_agent_pool_get_default_agent_pool_agents_pq_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_condition_configuration_request as kf_keyfactor_api_models_workflows_condition_configuration_request
import \
    keyfactor_v_1_client.models.models_query_models_paged_denied_alert_query_sort_ascending as kf_models_query_models_paged_denied_alert_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_alert_schedule_alert_schedule_response as kf_keyfactor_api_models_alerts_alert_schedule_alert_schedule_response
import \
    keyfactor_v_1_client.models.models_certificate_store_inventory_parameters_additional_property as kf_models_certificate_store_inventory_parameters_additional_property
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_collections_certificate_collection_copy_request as kf_keyfactor_api_models_certificate_collections_certificate_collection_copy_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_metadata_field_metadata_field_response as kf_keyfactor_api_models_metadata_field_metadata_field_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_stores_types_certificate_store_type_update_request_private_key_allowed as kf_keyfactor_api_models_certificate_stores_types_certificate_store_type_update_request_private_key_allowed
import \
    keyfactor_v_1_client.models.models_query_models_paged_report_query as kf_models_query_models_paged_report_query
import \
    keyfactor_v_1_client.models.models_query_models_paged_security_identity_query_sort_ascending as kf_models_query_models_paged_security_identity_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_template_collection_retrieval_response_template_enrollment_field_model as kf_models_template_collection_retrieval_response_template_enrollment_field_model
import \
    keyfactor_v_1_client.models.models_template_collection_retrieval_response_allowed_enrollment_types as kf_models_template_collection_retrieval_response_allowed_enrollment_types
import \
    keyfactor_v_1_client.models.models_certificate_authorities_certificate_authority_response as kf_models_certificate_authorities_certificate_authority_response
import \
    keyfactor_v_1_client.models.audit_log_get_audit_log_response_200 as kf_audit_log_get_audit_log_response_200
import \
    keyfactor_v_1_client.models.models_query_models_paged_certificate_request_query_sort_ascending as kf_models_query_models_paged_certificate_request_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_certificate_retrieval_response_metadata as kf_models_certificate_retrieval_response_metadata
import \
    keyfactor_v_1_client.models.pending_alert_get_pending_alerts_paged_query_sort_ascending as kf_pending_alert_get_pending_alerts_paged_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_template_update_request_template_default_model as kf_models_template_update_request_template_default_model
import \
    keyfactor_v_1_client.models.models_ssh_service_accounts_service_account_user_creation_request as kf_models_ssh_service_accounts_service_account_user_creation_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_stores_reenrollment_request as kf_keyfactor_api_models_certificate_stores_reenrollment_request
import \
    keyfactor_v_1_client.models.models_template_retrieval_response_template_regex_model as kf_models_template_retrieval_response_template_regex_model
import \
    keyfactor_v_1_client.models.certificate_store_type_get_types_cstquery_sort_ascending as kf_certificate_store_type_get_types_cstquery_sort_ascending
import \
    keyfactor_v_1_client.models.models_paged_query_sort_ascending as kf_models_paged_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_query_models_paged_audit_log_query as kf_models_query_models_paged_audit_log_query
import \
    keyfactor_v_1_client.models.agent_blueprint_get_agent_blueprints_pq_sort_ascending as kf_agent_blueprint_get_agent_blueprints_pq_sort_ascending
import keyfactor_v_1_client.models.models_report_request_model as kf_models_report_request_model
import \
    keyfactor_v_1_client.models.keyfactor_api_models_ssl_network_response as kf_keyfactor_api_models_ssl_network_response
import \
    keyfactor_v_1_client.models.service_account_query_service_accounts_pq_sort_ascending as kf_service_account_query_service_accounts_pq_sort_ascending
import \
    keyfactor_v_1_client.models.models_monitoring_revocation_monitoring_alert_response as kf_models_monitoring_revocation_monitoring_alert_response
import \
    keyfactor_v_1_client.models.certificate_authority_get_cas_pq_sort_ascending as kf_certificate_authority_get_cas_pq_sort_ascending
import \
    keyfactor_v_1_client.models.models_ssh_service_accounts_service_account_creation_request as kf_models_ssh_service_accounts_service_account_creation_request
import \
    keyfactor_v_1_client.models.models_template_update_request_allowed_enrollment_types as kf_models_template_update_request_allowed_enrollment_types
import \
    keyfactor_v_1_client.models.models_query_models_paged_issued_alert_query as kf_models_query_models_paged_issued_alert_query
import \
    keyfactor_v_1_client.models.keyfactor_api_models_metadata_field_metadata_field_create_request_enrollment as kf_keyfactor_api_models_metadata_field_metadata_field_create_request_enrollment
import \
    keyfactor_v_1_client.models.reports_query_custom_reports_query_sort_ascending as kf_reports_query_custom_reports_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_cert_store_type_password_options as kf_models_cert_store_type_password_options
import keyfactor_v_1_client.models.models_orchestrator_jobs_job as kf_models_orchestrator_jobs_job
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_stores_certificate_store_approve_request as kf_keyfactor_api_models_certificate_stores_certificate_store_approve_request
import \
    keyfactor_v_1_client.models.models_query_models_paged_certificate_store_container_query as kf_models_query_models_paged_certificate_store_container_query
import \
    keyfactor_v_1_client.models.models_query_models_paged_pending_alert_query as kf_models_query_models_paged_pending_alert_query
import \
    keyfactor_v_1_client.models.keyfactor_api_models_monitoring_revocation_monitoring_alert_test_response_alert_build_result as kf_keyfactor_api_models_monitoring_revocation_monitoring_alert_test_response_alert_build_result
import \
    keyfactor_v_1_client.models.models_query_models_paged_metadata_field_query as kf_models_query_models_paged_metadata_field_query
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_signal_request_data_additional_property as kf_keyfactor_api_models_workflows_signal_request_data_additional_property
import \
    keyfactor_v_1_client.models.workflow_definition_query_available_steps_query_sort_ascending as kf_workflow_definition_query_available_steps_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_smtpsmtp_test_response as kf_keyfactor_api_models_smtpsmtp_test_response
import \
    keyfactor_v_1_client.models.models_certificate_store_type_property as kf_models_certificate_store_type_property
import \
    keyfactor_v_1_client.models.keyfactor_api_pam_provider_type_response as kf_keyfactor_api_pam_provider_type_response
import \
    keyfactor_v_1_client.models.models_certificate_retrieval_response_detailed_key_usage_model as kf_models_certificate_retrieval_response_detailed_key_usage_model
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_available_step_query_response_signals_definition as kf_keyfactor_api_models_workflows_available_step_query_response_signals_definition
import \
    keyfactor_v_1_client.models.models_query_models_paged_key_rotation_alert_query as kf_models_query_models_paged_key_rotation_alert_query
import \
    keyfactor_v_1_client.models.models_enrollment_csr_enrollment_request as kf_models_enrollment_csr_enrollment_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_pending_pending_alert_test_response_alert_build_result as kf_keyfactor_api_models_alerts_pending_pending_alert_test_response_alert_build_result
import \
    keyfactor_v_1_client.models.keyfactor_api_models_ssl_network_query_response as kf_keyfactor_api_models_ssl_network_query_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_security_roles_role_identities_request as kf_keyfactor_api_models_security_roles_role_identities_request
import \
    keyfactor_v_1_client.models.models_query_models_paged_agent_blueprint_jobs_query_sort_ascending as kf_models_query_models_paged_agent_blueprint_jobs_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_monitoring_dashboard_response as kf_keyfactor_api_models_monitoring_dashboard_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_enrollment_management_store_request as kf_keyfactor_api_models_enrollment_management_store_request
import \
    keyfactor_v_1_client.models.models_pkcs_12_certificate_response_enrollment_context as kf_models_pkcs_12_certificate_response_enrollment_context
import \
    keyfactor_v_1_client.models.keyfactor_api_models_orchestrators_agent_blueprint_jobs_response as kf_keyfactor_api_models_orchestrators_agent_blueprint_jobs_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_orchestrator_jobs_job_type_response as kf_keyfactor_api_models_orchestrator_jobs_job_type_response
import \
    keyfactor_v_1_client.models.models_workflow_certificate_request_model_metadata as kf_models_workflow_certificate_request_model_metadata
import \
    keyfactor_v_1_client.models.models_certificate_store_inventory as kf_models_certificate_store_inventory
import \
    keyfactor_v_1_client.models.keyfactor_common_scheduling_models_time_model as kf_keyfactor_common_scheduling_models_time_model
import keyfactor_v_1_client.models.models_report as kf_models_report
import \
    keyfactor_v_1_client.models.models_cert_store_locations_certificate_store_locations_detail as kf_models_cert_store_locations_certificate_store_locations_detail
import keyfactor_v_1_client.models.models_crl_request_model as kf_models_crl_request_model
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_issued_issued_alert_creation_request as kf_keyfactor_api_models_alerts_issued_issued_alert_creation_request
import \
    keyfactor_v_1_client.models.models_enrollment_csr_enrollment_response as kf_models_enrollment_csr_enrollment_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_templates_global_template_regex_request as kf_keyfactor_api_models_templates_global_template_regex_request
import \
    keyfactor_v_1_client.models.models_query_models_workflow_workflow_instance_query_sort_ascending as kf_models_query_models_workflow_workflow_instance_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_query_models_paged_security_role_query_sort_ascending as kf_models_query_models_paged_security_role_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_event_handler_event_handler_parameter_request as kf_keyfactor_api_models_event_handler_event_handler_parameter_request
import \
    keyfactor_v_1_client.models.models_certificate_store_container_list_response as kf_models_certificate_store_container_list_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_signal_configuration_request as kf_keyfactor_api_models_workflows_signal_configuration_request
import \
    keyfactor_v_1_client.models.models_certificate_authorities_certificate_authority_request_key_retention as kf_models_certificate_authorities_certificate_authority_request_key_retention
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_stores_reenrollment_request_job_properties as kf_keyfactor_api_models_certificate_stores_reenrollment_request_job_properties
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_denied_denied_alert_update_request as kf_keyfactor_api_models_alerts_denied_denied_alert_update_request
import \
    keyfactor_v_1_client.models.models_ssh_keys_unmanaged_key_response as kf_models_ssh_keys_unmanaged_key_response
import \
    keyfactor_v_1_client.models.models_pkcs_10_certificate_response as kf_models_pkcs_10_certificate_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_available_step_query_response_configuration_parameters_definition as kf_keyfactor_api_models_workflows_available_step_query_response_configuration_parameters_definition
import \
    keyfactor_v_1_client.models.models_certificate_retrieval_response_revocation_reason as kf_models_certificate_retrieval_response_revocation_reason
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_definition_step_response_configuration_parameters as kf_keyfactor_api_models_workflows_definition_step_response_configuration_parameters
import \
    keyfactor_v_1_client.models.ssl_get_networks_sq_sort_ascending as kf_ssl_get_networks_sq_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_parameter_definition_response_control_type as kf_keyfactor_api_models_workflows_parameter_definition_response_control_type
import \
    keyfactor_v_1_client.models.models_ssh_access_logon_user_access_request as kf_models_ssh_access_logon_user_access_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_stores_remove_certificate_request as kf_keyfactor_api_models_certificate_stores_remove_certificate_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_key_rotation_key_rotation_alert_response as kf_keyfactor_api_models_alerts_key_rotation_key_rotation_alert_response
import \
    keyfactor_v_1_client.models.ssl_network_scan_parts_paged_query_job_type as kf_ssl_network_scan_parts_paged_query_job_type
import \
    keyfactor_v_1_client.models.models_ssh_logons_logon_access_request as kf_models_ssh_logons_logon_access_request
import keyfactor_v_1_client.models.models_recovery_response as kf_models_recovery_response
import \
    keyfactor_v_1_client.models.models_certificate_store_entry_job_fields as kf_models_certificate_store_entry_job_fields
import keyfactor_v_1_client.models.models_report_schedule as kf_models_report_schedule
import \
    keyfactor_v_1_client.models.models_ssh_users_ssh_user_update_request as kf_models_ssh_users_ssh_user_update_request
import \
    keyfactor_v_1_client.models.models_certificate_validation_response_results as kf_models_certificate_validation_response_results
import \
    keyfactor_v_1_client.models.ssl_network_scan_parts_paged_query_sort_ascending as kf_ssl_network_scan_parts_paged_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_pkcs_10_certificate_response_enrollment_context as kf_models_pkcs_10_certificate_response_enrollment_context
import \
    keyfactor_v_1_client.models.keyfactor_api_models_ssl_quiet_hour_request_start_day as kf_keyfactor_api_models_ssl_quiet_hour_request_start_day
import \
    keyfactor_v_1_client.models.keyfactor_api_models_license_license_response_licensed_product as kf_keyfactor_api_models_license_license_response_licensed_product
import \
    keyfactor_v_1_client.models.models_invalid_keystore_reason as kf_models_invalid_keystore_reason
import \
    keyfactor_v_1_client.models.core_models_enrollment_enrollment_ca as kf_core_models_enrollment_enrollment_ca
import \
    keyfactor_v_1_client.models.keyfactor_api_pam_provider_type_parameter_response_data_type as kf_keyfactor_api_pam_provider_type_parameter_response_data_type
import \
    keyfactor_v_1_client.models.workflow_instance_query_instances_started_by_me_instance_query_sort_ascending as kf_workflow_instance_query_instances_started_by_me_instance_query_sort_ascending
import keyfactor_v_1_client.models.models_report_parameters as kf_models_report_parameters
import \
    keyfactor_v_1_client.models.models_template_update_request_template_policy_model as kf_models_template_update_request_template_policy_model
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_definition_response as kf_keyfactor_api_models_workflows_definition_response
import \
    keyfactor_v_1_client.models.models_workflow_approve_deny_result as kf_models_workflow_approve_deny_result
import \
    keyfactor_v_1_client.models.models_query_models_paged_ssh_service_account_query as kf_models_query_models_paged_ssh_service_account_query
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_stores_reenrollment_request_job_properties_additional_property as kf_keyfactor_api_models_certificate_stores_reenrollment_request_job_properties_additional_property
import \
    keyfactor_v_1_client.models.models_template_update_request as kf_models_template_update_request
import \
    keyfactor_v_1_client.models.models_pkcs_12_certificate_response as kf_models_pkcs_12_certificate_response
import \
    keyfactor_v_1_client.models.models_ssh_users_ssh_user_access_response as kf_models_ssh_users_ssh_user_access_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_definition_step_response_outputs as kf_keyfactor_api_models_workflows_definition_step_response_outputs
import \
    keyfactor_v_1_client.models.core_models_enrollment_enrollment_template as kf_core_models_enrollment_enrollment_template
import \
    keyfactor_v_1_client.models.models_collection_role_permissions as kf_models_collection_role_permissions
import \
    keyfactor_v_1_client.models.key_rotation_alert_get_key_rotation_alerts_paged_query_sort_ascending as kf_key_rotation_alert_get_key_rotation_alerts_paged_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_certificate_authorities_certificate_authority_request_allowed_enrollment_types as kf_models_certificate_authorities_certificate_authority_request_allowed_enrollment_types
import \
    keyfactor_v_1_client.models.models_security_certificate_permissions as kf_models_security_certificate_permissions
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_available_signal_response as kf_keyfactor_api_models_workflows_available_signal_response
import \
    keyfactor_v_1_client.models.models_query_models_paged_agent_pool_agents_query as kf_models_query_models_paged_agent_pool_agents_query
import \
    keyfactor_v_1_client.models.models_revocation_revocation_response as kf_models_revocation_revocation_response
import \
    keyfactor_v_1_client.models.models_enrollment_csr_enrollment_request_additional_enrollment_fields as kf_models_enrollment_csr_enrollment_request_additional_enrollment_fields
import \
    keyfactor_v_1_client.models.keyfactor_api_models_orchestrator_jobs_unschedule_job_request as kf_keyfactor_api_models_orchestrator_jobs_unschedule_job_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_stores_types_certificate_store_type_creation_request_private_key_allowed as kf_keyfactor_api_models_certificate_stores_types_certificate_store_type_creation_request_private_key_allowed
import \
    keyfactor_v_1_client.models.models_certificate_recovery_request as kf_models_certificate_recovery_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_orchestrators_update_orchestrator_auth_certificate_reenrollment_response as kf_keyfactor_api_models_orchestrators_update_orchestrator_auth_certificate_reenrollment_response
import \
    keyfactor_v_1_client.models.models_query_models_paged_legacy_denied_request_query_sort_ascending as kf_models_query_models_paged_legacy_denied_request_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_expiration_expiration_alert_update_request as kf_keyfactor_api_models_alerts_expiration_expiration_alert_update_request
import \
    keyfactor_v_1_client.models.models_query_models_paged_certificate_request_query as kf_models_query_models_paged_certificate_request_query
import \
    keyfactor_v_1_client.models.keyfactor_api_models_metadata_field_metadata_field_response_enrollment as kf_keyfactor_api_models_metadata_field_metadata_field_response_enrollment
import \
    keyfactor_v_1_client.models.models_query_models_paged_ssl_result_query as kf_models_query_models_paged_ssl_result_query
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_instance_response_initial_data as kf_keyfactor_api_models_workflows_instance_response_initial_data
import \
    keyfactor_v_1_client.models.keyfactor_common_scheduling_keyfactor_schedule as kf_keyfactor_common_scheduling_keyfactor_schedule
import \
    keyfactor_v_1_client.models.keyfactor_api_models_smtpsmtp_response as kf_keyfactor_api_models_smtpsmtp_response
import \
    keyfactor_v_1_client.models.models_template_retrieval_response_key_retention as kf_models_template_retrieval_response_key_retention
import \
    keyfactor_v_1_client.models.models_report_parameters_parameter_type as kf_models_report_parameters_parameter_type
import \
    keyfactor_v_1_client.models.models_template_retrieval_response_extended_key_usage_model as kf_models_template_retrieval_response_extended_key_usage_model
import \
    keyfactor_v_1_client.models.models_query_models_paged_key_rotation_alert_query_sort_ascending as kf_models_query_models_paged_key_rotation_alert_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_key_rotation_key_rotation_alert_test_all_request as kf_keyfactor_api_models_alerts_key_rotation_key_rotation_alert_test_all_request
import \
    keyfactor_v_1_client.models.models_orchestrator_jobs_job_type_update_request as kf_models_orchestrator_jobs_job_type_update_request
import \
    keyfactor_v_1_client.models.models_certificate_authorities_certificate_authority_request as kf_models_certificate_authorities_certificate_authority_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_parameter_definition_response_parameter_type as kf_keyfactor_api_models_workflows_parameter_definition_response_parameter_type
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_pending_pending_alert_test_response as kf_keyfactor_api_models_alerts_pending_pending_alert_test_response
import \
    keyfactor_v_1_client.models.models_security_identities_security_identity_lookup_response as kf_models_security_identities_security_identity_lookup_response
import \
    keyfactor_v_1_client.models.models_template_retrieval_response_template_policy_model as kf_models_template_retrieval_response_template_policy_model
import \
    keyfactor_v_1_client.models.keyfactor_api_models_orchestrators_agent_response_agent_platform as kf_keyfactor_api_models_orchestrators_agent_response_agent_platform
import \
    keyfactor_v_1_client.models.core_models_enrollment_enrollment_template_ca_response as kf_core_models_enrollment_enrollment_template_ca_response
import \
    keyfactor_v_1_client.models.models_query_models_paged_scan_job_parts_query_job_type as kf_models_query_models_paged_scan_job_parts_query_job_type
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_available_step_response_signals_definition as kf_keyfactor_api_models_workflows_available_step_response_signals_definition
import \
    keyfactor_v_1_client.models.audit_log_get_related_entities_pq_sort_ascending as kf_audit_log_get_related_entities_pq_sort_ascending
import \
    keyfactor_v_1_client.models.models_ssh_server_groups_server_group_creation_request as kf_models_ssh_server_groups_server_group_creation_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_security_roles_container_permission_response as kf_keyfactor_api_models_security_roles_container_permission_response
import \
    keyfactor_v_1_client.models.models_ssl_scan_job_part_definition as kf_models_ssl_scan_job_part_definition
import \
    keyfactor_v_1_client.models.agent_get_agents_pq_sort_ascending as kf_agent_get_agents_pq_sort_ascending
import keyfactor_v_1_client.models.models_ssl_scan_job_part as kf_models_ssl_scan_job_part
import \
    keyfactor_v_1_client.models.models_security_identities_security_identity_request as kf_models_security_identities_security_identity_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_expiration_expiration_alert_test_request as kf_keyfactor_api_models_alerts_expiration_expiration_alert_test_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_parameter_definition_response_potential_values as kf_keyfactor_api_models_workflows_parameter_definition_response_potential_values
import \
    keyfactor_v_1_client.models.keyfactor_api_models_ssl_update_network_request as kf_keyfactor_api_models_ssl_update_network_request
import \
    keyfactor_v_1_client.models.models_workflow_certificate_request_details_model as kf_models_workflow_certificate_request_details_model
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificates_certificate_identity_audit_response as kf_keyfactor_api_models_certificates_certificate_identity_audit_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_enrollment_management_store_request_properties as kf_keyfactor_api_models_enrollment_management_store_request_properties
import \
    keyfactor_v_1_client.models.keyfactor_api_models_orchestrator_jobs_job_type_field_response_type as kf_keyfactor_api_models_orchestrator_jobs_job_type_field_response_type
import \
    keyfactor_v_1_client.models.models_certificate_store_types_certificate_store_type_entry_parameter_required_when as kf_models_certificate_store_types_certificate_store_type_entry_parameter_required_when
import \
    keyfactor_v_1_client.models.key_get_unmanaged_keys_pq_sort_ascending as kf_key_get_unmanaged_keys_pq_sort_ascending
import \
    keyfactor_v_1_client.models.models_query_models_paged_ssh_unmanaged_key_query as kf_models_query_models_paged_ssh_unmanaged_key_query
import \
    keyfactor_v_1_client.models.metadata_field_get_all_metadata_fields_pq_sort_ascending as kf_metadata_field_get_all_metadata_fields_pq_sort_ascending
import \
    keyfactor_v_1_client.models.models_certificate_retrieval_response_extended_key_usage_model as kf_models_certificate_retrieval_response_extended_key_usage_model
import \
    keyfactor_v_1_client.models.models_security_security_roles_security_role_update_request as kf_models_security_security_roles_security_role_update_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_event_handler_event_handler_parameter_response as kf_keyfactor_api_models_event_handler_event_handler_parameter_response
import \
    keyfactor_v_1_client.models.models_ssl_endpoint_history_response_job_type as kf_models_ssl_endpoint_history_response_job_type
import \
    keyfactor_v_1_client.models.keyfactor_api_models_templates_template_enrollment_regex_response as kf_keyfactor_api_models_templates_template_enrollment_regex_response
import \
    keyfactor_v_1_client.models.models_query_models_paged_certificate_store_inventory_query as kf_models_query_models_paged_certificate_store_inventory_query
import \
    keyfactor_v_1_client.models.keyfactor_api_models_orchestrator_jobs_job_response as kf_keyfactor_api_models_orchestrator_jobs_job_response
import keyfactor_v_1_client.models.models_csr_contents as kf_models_csr_contents
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificates_certificate_query_request_sort_ascending as kf_keyfactor_api_models_certificates_certificate_query_request_sort_ascending
import \
    keyfactor_v_1_client.models.models_cert_store_type_password_options_style as kf_models_cert_store_type_password_options_style
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_pending_pending_alert_test_request as kf_keyfactor_api_models_alerts_pending_pending_alert_test_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_definition_step_response as kf_keyfactor_api_models_workflows_definition_step_response
import \
    keyfactor_v_1_client.models.models_query_models_paged_ssh_server_group_query as kf_models_query_models_paged_ssh_server_group_query
import \
    keyfactor_v_1_client.models.orchestrator_job_get_scheduled_jobs_pq_sort_ascending as kf_orchestrator_job_get_scheduled_jobs_pq_sort_ascending
import \
    keyfactor_v_1_client.models.models_query_models_paged_agent_blueprint_query as kf_models_query_models_paged_agent_blueprint_query
import \
    keyfactor_v_1_client.models.models_query_models_paged_ssh_server_group_query_sort_ascending as kf_models_query_models_paged_ssh_server_group_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_orchestrator_jobs_schedule_job_request as kf_models_orchestrator_jobs_schedule_job_request
import \
    keyfactor_v_1_client.models.models_certificate_store_inventory_certificates as kf_models_certificate_store_inventory_certificates
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_key_rotation_key_rotation_alert_definition_response as kf_keyfactor_api_models_alerts_key_rotation_key_rotation_alert_definition_response
import \
    keyfactor_v_1_client.models.models_ssh_server_groups_server_group_update_request as kf_models_ssh_server_groups_server_group_update_request
import \
    keyfactor_v_1_client.models.models_query_models_paged_agent_pool_query_sort_ascending as kf_models_query_models_paged_agent_pool_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_alert_template_alert_template_response as kf_keyfactor_api_models_alerts_alert_template_alert_template_response
import \
    keyfactor_v_1_client.models.models_ssl_network_definition_item_type as kf_models_ssl_network_definition_item_type
import \
    keyfactor_v_1_client.models.models_query_models_paged_certificate_authority_query as kf_models_query_models_paged_certificate_authority_query
import \
    keyfactor_v_1_client.models.models_subject_alternative_name_type as kf_models_subject_alternative_name_type
import \
    keyfactor_v_1_client.models.models_ssl_endpoint_status_request as kf_models_ssl_endpoint_status_request
import \
    keyfactor_v_1_client.models.models_query_models_paged_agent_blueprint_jobs_query as kf_models_query_models_paged_agent_blueprint_jobs_query
import \
    keyfactor_v_1_client.models.models_metadata_single_update_request as kf_models_metadata_single_update_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_key_rotation_key_rotation_alert_update_request as kf_keyfactor_api_models_alerts_key_rotation_key_rotation_alert_update_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_stores_types_certificate_store_type_update_request_custom_alias_allowed as kf_keyfactor_api_models_certificate_stores_types_certificate_store_type_update_request_custom_alias_allowed
import \
    keyfactor_v_1_client.models.models_workflow_certificate_request_model as kf_models_workflow_certificate_request_model
import \
    keyfactor_v_1_client.models.keyfactor_api_models_templates_template_enrollment_default_response as kf_keyfactor_api_models_templates_template_enrollment_default_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_monitoring_ocsp_parameters_response as kf_keyfactor_api_models_monitoring_ocsp_parameters_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_authorities_certificate_authority_test_response as kf_keyfactor_api_models_certificate_authorities_certificate_authority_test_response
import \
    keyfactor_v_1_client.models.models_ssh_keys_key_update_request as kf_models_ssh_keys_key_update_request
import \
    keyfactor_v_1_client.models.models_query_models_paged_revocation_monitoring_query_sort_ascending as kf_models_query_models_paged_revocation_monitoring_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_query_models_paged_ssl_result_query_sort_ascending as kf_models_query_models_paged_ssl_result_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_query_models_paged_pending_csr_query as kf_models_query_models_paged_pending_csr_query
import \
    keyfactor_v_1_client.models.agent_blueprint_get_blueprint_jobs_pq_sort_ascending as kf_agent_blueprint_get_blueprint_jobs_pq_sort_ascending
import \
    keyfactor_v_1_client.models.models_revoke_certificate_request as kf_models_revoke_certificate_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_orchestrators_agent_blueprint_response as kf_keyfactor_api_models_orchestrators_agent_blueprint_response
import \
    keyfactor_v_1_client.models.models_template_retrieval_response_template_enrollment_field_model_data_type as kf_models_template_retrieval_response_template_enrollment_field_model_data_type
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_denied_denied_alert_creation_request as kf_keyfactor_api_models_alerts_denied_denied_alert_creation_request
import \
    keyfactor_v_1_client.models.keyfactor_api_pam_provider_type_create_request as kf_keyfactor_api_pam_provider_type_create_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_security_roles_container_permission_request as kf_keyfactor_api_models_security_roles_container_permission_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_definition_create_request as kf_keyfactor_api_models_workflows_definition_create_request
import keyfactor_v_1_client.models.models_agents_agent_pool as kf_models_agents_agent_pool
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_definition_step_signal_response as kf_keyfactor_api_models_workflows_definition_step_signal_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_stores_types_certificate_store_type_creation_request as kf_keyfactor_api_models_certificate_stores_types_certificate_store_type_creation_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_orchestrator_jobs_job_field_response as kf_keyfactor_api_models_orchestrator_jobs_job_field_response
import \
    keyfactor_v_1_client.models.models_certificate_location_specifier as kf_models_certificate_location_specifier
import \
    keyfactor_v_1_client.models.models_csr_generation_response_model as kf_models_csr_generation_response_model
import \
    keyfactor_v_1_client.models.models_enrollment_pfx_enrollment_request_additional_enrollment_fields as kf_models_enrollment_pfx_enrollment_request_additional_enrollment_fields
import \
    keyfactor_v_1_client.models.models_query_models_paged_custom_report_query_sort_ascending as kf_models_query_models_paged_custom_report_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_license_license_response as kf_keyfactor_api_models_license_license_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_definition_query_response as kf_keyfactor_api_models_workflows_definition_query_response
import \
    keyfactor_v_1_client.models.reports_query_reports_query_sort_ascending as kf_reports_query_reports_query_sort_ascending
import keyfactor_v_1_client.models.models_ssl_endpoint as kf_models_ssl_endpoint
import \
    keyfactor_v_1_client.models.models_ssh_users_ssh_user_creation_request as kf_models_ssh_users_ssh_user_creation_request
import keyfactor_v_1_client.models.models_reenrollment_status as kf_models_reenrollment_status
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_condition_configuration_response as kf_keyfactor_api_models_workflows_condition_configuration_response
import \
    keyfactor_v_1_client.models.certificate_store_get_certificate_store_inventory_query_sort_ascending as kf_certificate_store_get_certificate_store_inventory_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_revoke_all_certificates_request_reason as kf_models_revoke_all_certificates_request_reason
import \
    keyfactor_v_1_client.models.models_revoke_all_certificates_request as kf_models_revoke_all_certificates_request
import \
    keyfactor_v_1_client.models.models_enrollment_renewal_response as kf_models_enrollment_renewal_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_orchestrator_jobs_bulk_job_response as kf_keyfactor_api_models_orchestrator_jobs_bulk_job_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_pending_pending_alert_creation_request as kf_keyfactor_api_models_alerts_pending_pending_alert_creation_request
import \
    keyfactor_v_1_client.models.models_template_metadata_field_enrollment as kf_models_template_metadata_field_enrollment
import \
    keyfactor_v_1_client.models.denied_alert_get_denied_alerts_paged_query_sort_ascending as kf_denied_alert_get_denied_alerts_paged_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_security_roles_identities_security_roles_global_permission_request as kf_keyfactor_api_models_security_roles_identities_security_roles_global_permission_request
import \
    keyfactor_v_1_client.models.models_certificate_import_response_model_import_status as kf_models_certificate_import_response_model_import_status
import \
    keyfactor_v_1_client.models.keyfactor_api_models_orchestrators_agent_response as kf_keyfactor_api_models_orchestrators_agent_response
import \
    keyfactor_v_1_client.models.models_ssh_access_logon_user_access_response as kf_models_ssh_access_logon_user_access_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificates_certificate_query_request as kf_keyfactor_api_models_certificates_certificate_query_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_expiration_expiration_alert_test_all_request as kf_keyfactor_api_models_alerts_expiration_expiration_alert_test_all_request
import keyfactor_v_1_client.models.models_extended_key_usage as kf_models_extended_key_usage
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_issued_issued_alert_update_request as kf_keyfactor_api_models_alerts_issued_issued_alert_update_request
import keyfactor_v_1_client.models.models_ssh_keys_key_response as kf_models_ssh_keys_key_response
import \
    keyfactor_v_1_client.models.models_template_collection_retrieval_response as kf_models_template_collection_retrieval_response
import \
    keyfactor_v_1_client.models.models_workflow_processed_certificate_request as kf_models_workflow_processed_certificate_request
import \
    keyfactor_v_1_client.models.models_ssl_scan_job_part_status as kf_models_ssl_scan_job_part_status
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_instance_response_current_state_data as kf_keyfactor_api_models_workflows_instance_response_current_state_data
import \
    keyfactor_v_1_client.models.models_orchestrator_jobs_schedule_bulk_job_request as kf_models_orchestrator_jobs_schedule_bulk_job_request
import \
    keyfactor_v_1_client.models.issued_alert_get_issued_alerts_paged_query_sort_ascending as kf_issued_alert_get_issued_alerts_paged_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_ssl_quiet_hour_response as kf_keyfactor_api_models_ssl_quiet_hour_response
import \
    keyfactor_v_1_client.models.models_certificate_store_inventory_parameters as kf_models_certificate_store_inventory_parameters
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_available_step_response_configuration_parameters_definition as kf_keyfactor_api_models_workflows_available_step_response_configuration_parameters_definition
import \
    keyfactor_v_1_client.models.models_certificate_download_request as kf_models_certificate_download_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_definition_step_request_configuration_parameters_additional_property as kf_keyfactor_api_models_workflows_definition_step_request_configuration_parameters_additional_property
import \
    keyfactor_v_1_client.models.models_ssl_endpoint_history_response_probe_type as kf_models_ssl_endpoint_history_response_probe_type
import \
    keyfactor_v_1_client.models.workflow_get_denied_paged_query_sort_ascending as kf_workflow_get_denied_paged_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_pam_provider_type_parameter_create_request_data_type as kf_keyfactor_api_pam_provider_type_parameter_create_request_data_type
import \
    keyfactor_v_1_client.models.models_query_models_paged_issued_alert_query_sort_ascending as kf_models_query_models_paged_issued_alert_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_metadata_field_metadata_field_update_request_data_type as kf_keyfactor_api_models_metadata_field_metadata_field_update_request_data_type
import \
    keyfactor_v_1_client.models.models_query_models_paged_certificate_history_query_sort_ascending as kf_models_query_models_paged_certificate_history_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_query_models_paged_expiration_alert_query as kf_models_query_models_paged_expiration_alert_query
import \
    keyfactor_v_1_client.models.keyfactor_api_models_orchestrators_agent_blueprint_stores_response as kf_keyfactor_api_models_orchestrators_agent_blueprint_stores_response
import \
    keyfactor_v_1_client.models.models_ssh_service_accounts_service_account_response as kf_models_ssh_service_accounts_service_account_response
import \
    keyfactor_v_1_client.models.models_certificate_authorities_certificate_authority_response_ca_type as kf_models_certificate_authorities_certificate_authority_response_ca_type
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_pending_pending_alert_test_all_request as kf_keyfactor_api_models_alerts_pending_pending_alert_test_all_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_monitoring_email_response as kf_keyfactor_api_models_monitoring_email_response
import \
    keyfactor_v_1_client.models.models_certificate_retrieval_response_key_type as kf_models_certificate_retrieval_response_key_type
import \
    keyfactor_v_1_client.models.models_certificate_retrieval_response_certificate_store_location_detail_model as kf_models_certificate_retrieval_response_certificate_store_location_detail_model
import \
    keyfactor_v_1_client.models.models_certificate_store_inventory_certificates_metadata_additional_property as kf_models_certificate_store_inventory_certificates_metadata_additional_property
import \
    keyfactor_v_1_client.models.reports_get_report_schedules_pq_sort_ascending as kf_reports_get_report_schedules_pq_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_signal_definition_response as kf_keyfactor_api_models_workflows_signal_definition_response
import \
    keyfactor_v_1_client.models.models_template_retrieval_response as kf_models_template_retrieval_response
import \
    keyfactor_v_1_client.models.models_custom_report_creation_request as kf_models_custom_report_creation_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_templates_global_template_settings_response as kf_keyfactor_api_models_templates_global_template_settings_response
import \
    keyfactor_v_1_client.models.models_certificate_store_types_certificate_store_type_entry_parameter_type as kf_models_certificate_store_types_certificate_store_type_entry_parameter_type
import \
    keyfactor_v_1_client.models.logon_query_logons_pq_sort_ascending as kf_logon_query_logons_pq_sort_ascending
import \
    keyfactor_v_1_client.models.models_query_models_paged_certificate_store_container_query_sort_ascending as kf_models_query_models_paged_certificate_store_container_query_sort_ascending
import keyfactor_v_1_client.models.models_certificate_query as kf_models_certificate_query
import \
    keyfactor_v_1_client.models.models_enrollment_csr_enrollment_response_metadata as kf_models_enrollment_csr_enrollment_response_metadata
import \
    keyfactor_v_1_client.models.keyfactor_api_models_metadata_field_metadata_field_create_request_data_type as kf_keyfactor_api_models_metadata_field_metadata_field_create_request_data_type
import \
    keyfactor_v_1_client.models.models_query_models_paged_agent_job_query_sort_ascending as kf_models_query_models_paged_agent_job_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_query_models_paged_template_query as kf_models_query_models_paged_template_query
import \
    keyfactor_v_1_client.models.agent_blueprint_get_blueprint_stores_pq_sort_ascending as kf_agent_blueprint_get_blueprint_stores_pq_sort_ascending
import keyfactor_v_1_client.models.models_cert_stores_schedule as kf_models_cert_stores_schedule
import \
    keyfactor_v_1_client.models.workflow_definition_query_query_sort_ascending as kf_workflow_definition_query_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_stores_types_certificate_store_type_update_request as kf_keyfactor_api_models_certificate_stores_types_certificate_store_type_update_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_collections_certificate_collection_create_request_duplication_field as kf_keyfactor_api_models_certificate_collections_certificate_collection_create_request_duplication_field
import \
    keyfactor_v_1_client.models.keyfactor_api_models_security_roles_role_identities_response as kf_keyfactor_api_models_security_roles_role_identities_response
import \
    keyfactor_v_1_client.models.models_ssh_logons_logon_query_response as kf_models_ssh_logons_logon_query_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_expiration_expiration_alert_creation_request as kf_keyfactor_api_models_alerts_expiration_expiration_alert_creation_request
import \
    keyfactor_v_1_client.models.models_query_models_paged_certificate_history_query as kf_models_query_models_paged_certificate_history_query
import keyfactor_v_1_client.models.models_paged_query as kf_models_paged_query
import \
    keyfactor_v_1_client.models.models_enrollment_available_renewal_available_renewal_type as kf_models_enrollment_available_renewal_available_renewal_type
import \
    keyfactor_v_1_client.models.models_query_models_paged_certificate_store_query as kf_models_query_models_paged_certificate_store_query
import \
    keyfactor_v_1_client.models.keyfactor_api_models_enrollment_enrollment_management_response as kf_keyfactor_api_models_enrollment_enrollment_management_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_stores_types_certificate_store_type_response_custom_alias_allowed as kf_keyfactor_api_models_certificate_stores_types_certificate_store_type_response_custom_alias_allowed
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_collections_certificate_collection_update_request as kf_keyfactor_api_models_certificate_collections_certificate_collection_update_request
import \
    keyfactor_v_1_client.models.models_certificate_store_update_server_request as kf_models_certificate_store_update_server_request
import \
    keyfactor_v_1_client.models.models_enrollment_pfx_enrollment_request as kf_models_enrollment_pfx_enrollment_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_expiration_expiration_alert_test_response as kf_keyfactor_api_models_alerts_expiration_expiration_alert_test_response
import \
    keyfactor_v_1_client.models.models_report_parameters_parameter_visibility as kf_models_report_parameters_parameter_visibility
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_denied_denied_alert_definition_response as kf_keyfactor_api_models_alerts_denied_denied_alert_definition_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_instance_definition_response as kf_keyfactor_api_models_workflows_instance_definition_response
import \
    keyfactor_v_1_client.models.models_query_models_paged_ssh_unmanaged_key_query_sort_ascending as kf_models_query_models_paged_ssh_unmanaged_key_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_query_models_paged_agent_job_history_query as kf_models_query_models_paged_agent_job_history_query
import \
    keyfactor_v_1_client.models.monitoring_get_revocation_monitoring_endpoints_paged_query_sort_ascending as kf_monitoring_get_revocation_monitoring_endpoints_paged_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_signal_definition_response_input_parameters as kf_keyfactor_api_models_workflows_signal_definition_response_input_parameters
import \
    keyfactor_v_1_client.models.models_ssh_access_server_access_response as kf_models_ssh_access_server_access_response
import \
    keyfactor_v_1_client.models.models_query_models_paged_security_identity_query as kf_models_query_models_paged_security_identity_query
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_collections_certificate_collection_response as kf_keyfactor_api_models_certificate_collections_certificate_collection_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_orchestrator_jobs_job_type_field_response as kf_keyfactor_api_models_orchestrator_jobs_job_type_field_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_templates_global_template_default_response as kf_keyfactor_api_models_templates_global_template_default_response
import \
    keyfactor_v_1_client.models.models_query_models_paged_certificate_store_server_query_sort_ascending as kf_models_query_models_paged_certificate_store_server_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_metadata_update_request_metadata as kf_models_metadata_update_request_metadata
import \
    keyfactor_v_1_client.models.models_template_enrollment_field_data_type as kf_models_template_enrollment_field_data_type
import \
    keyfactor_v_1_client.models.models_template_retrieval_response_template_metadata_field_model_enrollment as kf_models_template_retrieval_response_template_metadata_field_model_enrollment
import \
    keyfactor_v_1_client.models.keyfactor_api_models_ssl_network_query_response_monitor_status as kf_keyfactor_api_models_ssl_network_query_response_monitor_status
import \
    keyfactor_v_1_client.models.workflow_instance_query_instances_assigned_to_me_pq_sort_ascending as kf_workflow_instance_query_instances_assigned_to_me_pq_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificates_certificate_identity_audit_response_certificate_permission as kf_keyfactor_api_models_certificates_certificate_identity_audit_response_certificate_permission
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_instance_response_initial_data_additional_property as kf_keyfactor_api_models_workflows_instance_response_initial_data_additional_property
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_pending_pending_alert_definition_response as kf_keyfactor_api_models_alerts_pending_pending_alert_definition_response
import \
    keyfactor_v_1_client.models.models_query_models_paged_ssh_user_query_sort_ascending as kf_models_query_models_paged_ssh_user_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_common_scheduling_models_monthly_model as kf_keyfactor_common_scheduling_models_monthly_model
import \
    keyfactor_v_1_client.models.models_query_models_workflow_workflow_definition_query_sort_ascending as kf_models_query_models_workflow_workflow_definition_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_stores_types_certificate_store_type_response_private_key_allowed as kf_keyfactor_api_models_certificate_stores_types_certificate_store_type_response_private_key_allowed
import \
    keyfactor_v_1_client.models.models_template_enrollment_field as kf_models_template_enrollment_field
import keyfactor_v_1_client.models.models_custom_report as kf_models_custom_report
import \
    keyfactor_v_1_client.models.orchestrator_job_get_job_history_pq_sort_ascending as kf_orchestrator_job_get_job_history_pq_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_security_roles_area_permission_response as kf_keyfactor_api_models_security_roles_area_permission_response
import \
    keyfactor_v_1_client.models.models_ssl_endpoint_history_response as kf_models_ssl_endpoint_history_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_enrollment_management_store_type_request_properties_item as kf_keyfactor_api_models_enrollment_management_store_type_request_properties_item
import \
    keyfactor_v_1_client.models.keyfactor_api_models_templates_valid_subject_part_response as kf_keyfactor_api_models_templates_valid_subject_part_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_orchestrator_jobs_acknowledge_job_request as kf_keyfactor_api_models_orchestrator_jobs_acknowledge_job_request
import \
    keyfactor_v_1_client.models.models_query_models_workflow_workflow_step_schema_query_sort_ascending as kf_models_query_models_workflow_workflow_step_schema_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_ssh_access_server_group_access_request as kf_models_ssh_access_server_group_access_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_stores_job_history_response_status as kf_keyfactor_api_models_certificate_stores_job_history_response_status
import \
    keyfactor_v_1_client.models.audit_log_download_csv_pq_sort_ascending as kf_audit_log_download_csv_pq_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_monitoring_ocsp_parameters_request as kf_keyfactor_api_models_monitoring_ocsp_parameters_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_ssl_network_response_monitor_status as kf_keyfactor_api_models_ssl_network_response_monitor_status
import \
    keyfactor_v_1_client.models.models_query_models_paged_ssh_user_query as kf_models_query_models_paged_ssh_user_query
import keyfactor_v_1_client.models.models_keyfactor_api_secret as kf_models_keyfactor_api_secret
import \
    keyfactor_v_1_client.models.keyfactor_api_models_metadata_field_metadata_field_response_data_type as kf_keyfactor_api_models_metadata_field_metadata_field_response_data_type
import \
    keyfactor_v_1_client.models.csr_generation_get_pending_cs_rs_sq_sort_ascending as kf_csr_generation_get_pending_cs_rs_sq_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_signal_request as kf_keyfactor_api_models_workflows_signal_request
import \
    keyfactor_v_1_client.models.models_template_retrieval_response_template_enrollment_field_model as kf_models_template_retrieval_response_template_enrollment_field_model
import keyfactor_v_1_client.models.models_certificate_store as kf_models_certificate_store
import \
    keyfactor_v_1_client.models.keyfactor_api_models_ssl_quiet_hour_request_end_day as kf_keyfactor_api_models_ssl_quiet_hour_request_end_day
import \
    keyfactor_v_1_client.models.expiration_alert_get_expiration_alerts_paged_query_sort_ascending as kf_expiration_alert_get_expiration_alerts_paged_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_revocation_suspended_revocation_response as kf_models_revocation_suspended_revocation_response
import \
    keyfactor_v_1_client.models.models_certificate_authorities_certificate_authority_response_allowed_enrollment_types as kf_models_certificate_authorities_certificate_authority_response_allowed_enrollment_types
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_stores_job_history_response_result as kf_keyfactor_api_models_certificate_stores_job_history_response_result
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_signal_request_data as kf_keyfactor_api_models_workflows_signal_request_data
import \
    keyfactor_v_1_client.models.models_query_models_paged_pending_alert_query_sort_ascending as kf_models_query_models_paged_pending_alert_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_security_roles_identities_security_roles_collection_permission_response as kf_keyfactor_api_models_security_roles_identities_security_roles_collection_permission_response
import \
    keyfactor_v_1_client.models.models_query_models_paged_revocation_monitoring_query as kf_models_query_models_paged_revocation_monitoring_query
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_stores_add_certificate_request as kf_keyfactor_api_models_certificate_stores_add_certificate_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_collections_certificate_collection_response_duplication_field as kf_keyfactor_api_models_certificate_collections_certificate_collection_response_duplication_field
import \
    keyfactor_v_1_client.models.models_query_models_paged_audit_log_query_sort_ascending as kf_models_query_models_paged_audit_log_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_certificate_store_type_property_type as kf_models_certificate_store_type_property_type
import \
    keyfactor_v_1_client.models.keyfactor_api_models_orchestrator_jobs_custom_job_result_data_response as kf_keyfactor_api_models_orchestrator_jobs_custom_job_result_data_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_templates_template_enrollment_settings_response as kf_keyfactor_api_models_templates_template_enrollment_settings_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_security_roles_security_role_copy_request as kf_keyfactor_api_models_security_roles_security_role_copy_request
import \
    keyfactor_v_1_client.models.keyfactor_auditing_querying_audit_log_entry_level as kf_keyfactor_auditing_querying_audit_log_entry_level
import \
    keyfactor_v_1_client.models.keyfactor_api_models_mac_enrollment_mac_enrollment_api_model as kf_keyfactor_api_models_mac_enrollment_mac_enrollment_api_model
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificates_certificate_locations_response as kf_keyfactor_api_models_certificates_certificate_locations_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_definition_step_request_configuration_parameters as kf_keyfactor_api_models_workflows_definition_step_request_configuration_parameters
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_issued_issued_alert_definition_response as kf_keyfactor_api_models_alerts_issued_issued_alert_definition_response
import \
    keyfactor_v_1_client.models.models_workflow_certificate_request_details_model_metadata as kf_models_workflow_certificate_request_details_model_metadata
import \
    keyfactor_v_1_client.models.server_query_servers_pq_sort_ascending as kf_server_query_servers_pq_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_license_license_response_license as kf_keyfactor_api_models_license_license_response_license
import \
    keyfactor_v_1_client.models.models_security_security_roles_security_role_creation_request as kf_models_security_security_roles_security_role_creation_request
import \
    keyfactor_v_1_client.models.models_ssh_users_ssh_user_response as kf_models_ssh_users_ssh_user_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_ssl_network_query_response_discover_status as kf_keyfactor_api_models_ssl_network_query_response_discover_status
import \
    keyfactor_v_1_client.models.models_template_update_request_template_enrollment_field_model_data_type as kf_models_template_update_request_template_enrollment_field_model_data_type
import \
    keyfactor_v_1_client.models.models_query_models_paged_agent_job_history_query_sort_ascending as kf_models_query_models_paged_agent_job_history_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_template_update_request_template_enrollment_field_model as kf_models_template_update_request_template_enrollment_field_model
import \
    keyfactor_v_1_client.models.models_template_collection_retrieval_response_key_retention as kf_models_template_collection_retrieval_response_key_retention
import \
    keyfactor_v_1_client.models.models_query_models_paged_ssh_server_query_sort_ascending as kf_models_query_models_paged_ssh_server_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_orchestrators_update_orchestrator_auth_certificate_reenrollment_response_status as kf_keyfactor_api_models_orchestrators_update_orchestrator_auth_certificate_reenrollment_response_status
import \
    keyfactor_v_1_client.models.models_query_models_paged_ssh_server_query as kf_models_query_models_paged_ssh_server_query
import \
    keyfactor_v_1_client.models.keyfactor_common_scheduling_models_weekly_model_days_item as kf_keyfactor_common_scheduling_models_weekly_model_days_item
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_available_step_query_response as kf_keyfactor_api_models_workflows_available_step_query_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_license_license_response_licensed_feature as kf_keyfactor_api_models_license_license_response_licensed_feature
import \
    keyfactor_v_1_client.models.keyfactor_api_models_ssl_quiet_hour_request as kf_keyfactor_api_models_ssl_quiet_hour_request
import \
    keyfactor_v_1_client.models.models_query_models_paged_report_query_sort_ascending as kf_models_query_models_paged_report_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_query_models_paged_scan_job_parts_query as kf_models_query_models_paged_scan_job_parts_query
import \
    keyfactor_v_1_client.models.models_enrollment_pfx_enrollment_response as kf_models_enrollment_pfx_enrollment_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_license_license_response_licensed_customer as kf_keyfactor_api_models_license_license_response_licensed_customer
import \
    keyfactor_v_1_client.models.models_cert_store_new_password_request_new_password as kf_models_cert_store_new_password_request_new_password
import \
    keyfactor_v_1_client.models.models_certificate_authorities_certificate_authority_response_key_retention as kf_models_certificate_authorities_certificate_authority_response_key_retention
import \
    keyfactor_v_1_client.models.workflow_get_paged_query_sort_ascending as kf_workflow_get_paged_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_templates_global_template_regex_response as kf_keyfactor_api_models_templates_global_template_regex_response
import \
    keyfactor_v_1_client.models.models_template_collection_retrieval_response_template_regex_model as kf_models_template_collection_retrieval_response_template_regex_model
import \
    keyfactor_v_1_client.models.models_query_models_paged_legacy_denied_request_query as kf_models_query_models_paged_legacy_denied_request_query
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_alert_schedule_alert_schedule_request as kf_keyfactor_api_models_alerts_alert_schedule_alert_schedule_request
import \
    keyfactor_v_1_client.models.models_certificate_import_request_model_metadata as kf_models_certificate_import_request_model_metadata
import \
    keyfactor_v_1_client.models.ssl_endpoint_history_pq_sort_ascending as kf_ssl_endpoint_history_pq_sort_ascending
import \
    keyfactor_v_1_client.models.models_agents_agent_pool_agent as kf_models_agents_agent_pool_agent
import \
    keyfactor_v_1_client.models.models_metadata_all_update_request as kf_models_metadata_all_update_request
import \
    keyfactor_v_1_client.models.models_workflow_certificate_request_model_state as kf_models_workflow_certificate_request_model_state
import \
    keyfactor_v_1_client.models.keyfactor_api_models_orchestrators_agent_response_status as kf_keyfactor_api_models_orchestrators_agent_response_status
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_instance_query_response as kf_keyfactor_api_models_workflows_instance_query_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_monitoring_revocation_monitoring_alert_test_all_request as kf_keyfactor_api_models_monitoring_revocation_monitoring_alert_test_all_request
import \
    keyfactor_v_1_client.models.server_group_query_server_groups_pq_sort_ascending as kf_server_group_query_server_groups_pq_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_collections_certificate_collection_copy_request_duplication_field as kf_keyfactor_api_models_certificate_collections_certificate_collection_copy_request_duplication_field
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_parameter_definition_response_depends_on as kf_keyfactor_api_models_workflows_parameter_definition_response_depends_on
import \
    keyfactor_v_1_client.models.keyfactor_api_pam_provider_type_parameter_create_request as kf_keyfactor_api_pam_provider_type_parameter_create_request
import \
    keyfactor_v_1_client.models.models_ssl_display_scan_job_part as kf_models_ssl_display_scan_job_part
import \
    keyfactor_v_1_client.models.models_certificate_retrieval_response_subject_alternative_name_model as kf_models_certificate_retrieval_response_subject_alternative_name_model
import \
    keyfactor_v_1_client.models.keyfactor_api_models_templates_global_template_default_request as kf_keyfactor_api_models_templates_global_template_default_request
import \
    keyfactor_v_1_client.models.models_template_update_request_template_metadata_field_model as kf_models_template_update_request_template_metadata_field_model
import \
    keyfactor_v_1_client.models.models_cert_store_type_supported_operations as kf_models_cert_store_type_supported_operations
import \
    keyfactor_v_1_client.models.models_query_models_paged_agent_pool_agents_query_sort_ascending as kf_models_query_models_paged_agent_pool_agents_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_enrollment_management_store_request_properties_additional_property as kf_keyfactor_api_models_enrollment_management_store_request_properties_additional_property
import \
    keyfactor_v_1_client.models.models_custom_report_update_request as kf_models_custom_report_update_request
import \
    keyfactor_v_1_client.models.models_certificate_authorities_certificate_authority_request_ca_type as kf_models_certificate_authorities_certificate_authority_request_ca_type
import \
    keyfactor_v_1_client.models.keyfactor_api_models_smtpsmtp_test_request as kf_keyfactor_api_models_smtpsmtp_test_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_stores_types_certificate_store_type_response as kf_keyfactor_api_models_certificate_stores_types_certificate_store_type_response
import \
    keyfactor_v_1_client.models.models_ssh_access_server_group_access_response as kf_models_ssh_access_server_group_access_response
import \
    keyfactor_v_1_client.models.models_certificate_retrieval_response_subject_alternative_name_model_type as kf_models_certificate_retrieval_response_subject_alternative_name_model_type
import \
    keyfactor_v_1_client.models.models_security_identities_security_identity_permissions_response as kf_models_security_identities_security_identity_permissions_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_definition_step_request as kf_keyfactor_api_models_workflows_definition_step_request
import \
    keyfactor_v_1_client.models.models_template_retrieval_response_template_default_model as kf_models_template_retrieval_response_template_default_model
import \
    keyfactor_v_1_client.models.keyfactor_api_models_orchestrators_update_orchestrator_auth_certificate_reenrollment_request as kf_keyfactor_api_models_orchestrators_update_orchestrator_auth_certificate_reenrollment_request
import \
    keyfactor_v_1_client.models.certificate_certificate_history_query_sort_ascending as kf_certificate_certificate_history_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_template_update_request_template_regex_model as kf_models_template_update_request_template_regex_model
import \
    keyfactor_v_1_client.models.certificate_store_container_get_all_certificate_store_containers_pq_sort_ascending as kf_certificate_store_container_get_all_certificate_store_containers_pq_sort_ascending
import \
    keyfactor_v_1_client.models.models_query_models_paged_agent_query_sort_ascending as kf_models_query_models_paged_agent_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_query_models_workflow_workflow_definition_query as kf_models_query_models_workflow_workflow_definition_query
import \
    keyfactor_v_1_client.models.models_certificate_stores_certificate_store_create_request as kf_models_certificate_stores_certificate_store_create_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_stores_job_history_response as kf_keyfactor_api_models_certificate_stores_job_history_response
import \
    keyfactor_v_1_client.models.models_query_models_paged_security_role_query as kf_models_query_models_paged_security_role_query
import \
    keyfactor_v_1_client.models.keyfactor_api_models_event_handler_registered_event_handler_response as kf_keyfactor_api_models_event_handler_registered_event_handler_response
import \
    keyfactor_v_1_client.models.models_revoke_certificate_request_reason as kf_models_revoke_certificate_request_reason
import \
    keyfactor_v_1_client.models.keyfactor_api_models_orchestrator_jobs_reschedule_job_request as kf_keyfactor_api_models_orchestrator_jobs_reschedule_job_request
import keyfactor_v_1_client.models.models_container_assignment as kf_models_container_assignment
import \
    keyfactor_v_1_client.models.models_orchestrator_jobs_job_type_create_request as kf_models_orchestrator_jobs_job_type_create_request
import keyfactor_v_1_client.models.models_pending_csr_response as kf_models_pending_csr_response
import \
    keyfactor_v_1_client.models.models_query_models_paged_certificate_authority_query_sort_ascending as kf_models_query_models_paged_certificate_authority_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_template_retrieval_response_allowed_enrollment_types as kf_models_template_retrieval_response_allowed_enrollment_types
import \
    keyfactor_v_1_client.models.models_certificate_retrieval_response_certificate_store_inventory_item_model as kf_models_certificate_retrieval_response_certificate_store_inventory_item_model
import \
    keyfactor_v_1_client.models.keyfactor_api_models_templates_global_template_policy_response as kf_keyfactor_api_models_templates_global_template_policy_response
import \
    keyfactor_v_1_client.models.models_query_models_paged_agent_pool_query as kf_models_query_models_paged_agent_pool_query
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_key_rotation_key_rotation_alert_test_response_alert_build_result as kf_keyfactor_api_models_alerts_key_rotation_key_rotation_alert_test_response_alert_build_result
import \
    keyfactor_v_1_client.models.models_certificate_authorities_certificate_authority_auth_certificate as kf_models_certificate_authorities_certificate_authority_auth_certificate
import \
    keyfactor_v_1_client.models.models_report_schedule_runtime_parameters as kf_models_report_schedule_runtime_parameters
import \
    keyfactor_v_1_client.models.models_enrollment_management_store_type_properties_item as kf_models_enrollment_management_store_type_properties_item
import keyfactor_v_1_client.models.ssl_results_pq_sort_ascending as kf_ssl_results_pq_sort_ascending
import \
    keyfactor_v_1_client.models.models_certificate_validation_response as kf_models_certificate_validation_response
import \
    keyfactor_v_1_client.models.models_enrollment_pfx_enrollment_request_metadata as kf_models_enrollment_pfx_enrollment_request_metadata
import \
    keyfactor_v_1_client.models.models_workflow_denial_request as kf_models_workflow_denial_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_templates_global_template_policy_request as kf_keyfactor_api_models_templates_global_template_policy_request
import \
    keyfactor_v_1_client.models.models_certificate_store_server_response as kf_models_certificate_store_server_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_expiration_expiration_alert_definition_response as kf_keyfactor_api_models_alerts_expiration_expiration_alert_definition_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_collections_certificate_collection_update_request_duplication_field as kf_keyfactor_api_models_certificate_collections_certificate_collection_update_request_duplication_field
import \
    keyfactor_v_1_client.models.models_enrollment_existing_enrollment_management_request as kf_models_enrollment_existing_enrollment_management_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_monitoring_revocation_monitoring_update_request as kf_keyfactor_api_models_monitoring_revocation_monitoring_update_request
import \
    keyfactor_v_1_client.models.models_query_models_paged_ssh_logon_query as kf_models_query_models_paged_ssh_logon_query
import \
    keyfactor_v_1_client.models.models_orchestrator_jobs_job_type_field_request as kf_models_orchestrator_jobs_job_type_field_request
import \
    keyfactor_v_1_client.models.models_query_models_paged_agent_query as kf_models_query_models_paged_agent_query
import \
    keyfactor_v_1_client.models.models_enrollment_csr_enrollment_request_sa_ns as kf_models_enrollment_csr_enrollment_request_sa_ns
import \
    keyfactor_v_1_client.models.models_orchestrator_jobs_bulk_orchestrator_job_pair as kf_models_orchestrator_jobs_bulk_orchestrator_job_pair
import \
    keyfactor_v_1_client.models.keyfactor_api_models_configuration_tenant_configuration_tenant_request as kf_keyfactor_api_models_configuration_tenant_configuration_tenant_request
import \
    keyfactor_v_1_client.models.models_certificate_details_metadata as kf_models_certificate_details_metadata
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_parameter_definition_response as kf_keyfactor_api_models_workflows_parameter_definition_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_templates_template_enrollment_policy_response as kf_keyfactor_api_models_templates_template_enrollment_policy_response
import \
    keyfactor_v_1_client.models.models_certificate_retrieval_response_crl_distribution_point_model as kf_models_certificate_retrieval_response_crl_distribution_point_model
import \
    keyfactor_v_1_client.models.keyfactor_api_models_security_roles_identities_security_roles_collection_permission_request as kf_keyfactor_api_models_security_roles_identities_security_roles_collection_permission_request
import \
    keyfactor_v_1_client.models.models_query_models_workflow_workflow_instance_query as kf_models_query_models_workflow_workflow_instance_query
import \
    keyfactor_v_1_client.models.models_enrollment_pfx_enrollment_request_sa_ns as kf_models_enrollment_pfx_enrollment_request_sa_ns
import \
    keyfactor_v_1_client.models.workflow_instance_query_pq_sort_ascending as kf_workflow_instance_query_pq_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_alerts_pending_pending_alert_response as kf_keyfactor_api_models_alerts_pending_pending_alert_response
import \
    keyfactor_v_1_client.models.keyfactor_api_models_metadata_field_metadata_field_update_request as kf_keyfactor_api_models_metadata_field_metadata_field_update_request
import \
    keyfactor_v_1_client.models.models_query_models_paged_report_schedule_query as kf_models_query_models_paged_report_schedule_query
import \
    keyfactor_v_1_client.models.keyfactor_api_models_certificate_collections_certificate_collection_create_request as kf_keyfactor_api_models_certificate_collections_certificate_collection_create_request
import keyfactor_v_1_client.models.models_invalid_keystore as kf_models_invalid_keystore
import \
    keyfactor_v_1_client.models.models_subject_alternative_name as kf_models_subject_alternative_name
import \
    keyfactor_v_1_client.models.models_workflow_certificate_request_cert_store_model as kf_models_workflow_certificate_request_cert_store_model
import \
    keyfactor_v_1_client.models.models_enrollment_csr_enrollment_request_additional_enrollment_fields_additional_property as kf_models_enrollment_csr_enrollment_request_additional_enrollment_fields_additional_property
import \
    keyfactor_v_1_client.models.models_template_update_request_template_metadata_field_model_enrollment as kf_models_template_update_request_template_metadata_field_model_enrollment
import \
    keyfactor_v_1_client.models.models_orchestrator_jobs_schedule_bulk_job_request_job_fields as kf_models_orchestrator_jobs_schedule_bulk_job_request_job_fields
import \
    keyfactor_v_1_client.models.models_ssh_access_server_access_request as kf_models_ssh_access_server_access_request
import \
    keyfactor_v_1_client.models.models_ssh_service_accounts_service_account_update_request as kf_models_ssh_service_accounts_service_account_update_request
import \
    keyfactor_v_1_client.models.models_enrollment_pfx_enrollment_request_additional_enrollment_fields_additional_property as kf_models_enrollment_pfx_enrollment_request_additional_enrollment_fields_additional_property
import keyfactor_v_1_client.models.models_discovery_job_request as kf_models_discovery_job_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_monitoring_dashboard_request as kf_keyfactor_api_models_monitoring_dashboard_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_smtpsmtp_request as kf_keyfactor_api_models_smtpsmtp_request
import \
    keyfactor_v_1_client.models.workflow_definition_query_workflow_types_query_sort_ascending as kf_workflow_definition_query_workflow_types_query_sort_ascending
import \
    keyfactor_v_1_client.models.keyfactor_api_models_enrollment_enrollment_management_request as kf_keyfactor_api_models_enrollment_enrollment_management_request
import \
    keyfactor_v_1_client.models.models_query_models_paged_report_schedule_query_sort_ascending as kf_models_query_models_paged_report_schedule_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_certificate_retrieval_response as kf_models_certificate_retrieval_response
import \
    keyfactor_v_1_client.models.models_query_models_paged_ssh_service_account_query_sort_ascending as kf_models_query_models_paged_ssh_service_account_query_sort_ascending
import \
    keyfactor_v_1_client.models.models_certificate_store_inventory_certificates_metadata as kf_models_certificate_store_inventory_certificates_metadata
import \
    keyfactor_v_1_client.models.models_keyfactor_api_secret_parameters as kf_models_keyfactor_api_secret_parameters
import \
    keyfactor_v_1_client.models.models_enrollment_csr_generation_request as kf_models_enrollment_csr_generation_request
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_instance_query_response_status as kf_keyfactor_api_models_workflows_instance_query_response_status
import \
    keyfactor_v_1_client.models.keyfactor_api_models_workflows_instance_response as kf_keyfactor_api_models_workflows_instance_response
import \
    keyfactor_v_1_client.models.models_certificate_import_response_model as kf_models_certificate_import_response_model
import \
    keyfactor_v_1_client.models.models_ssl_display_scan_job_part_status as kf_models_ssl_display_scan_job_part_status


def format_username(username, domain):
    if not domain or '@' in username or domain in username:
        return username
    return f"{username}@{domain}"


def normalize(arg):
    return None if arg is None else arg.to_dict()


def getJson(filename):
    f = open(filename, "r")
    contents = f.read()
    f.close()
    data = json.loads(contents)
    return data


try:
    config = getJson(os.environ.get('KF_CONFIG', "environment.json"))
except FileNotFoundError:
    config = {
        "host": os.environ.get('KEYFACTOR_HOSTNAME', ""),
        "username": os.environ.get('KEYFACTOR_USERNAME', ""),
        "password": os.environ.get('KEYFACTOR_PASSWORD', ""),
        "domain": os.environ.get('KEYFACTOR_DOMAIN', ""),
        "scheme": os.environ.get('KEYFACTOR_SCHEME', "https"),
        "URLbase": os.environ.get('KEYFACTOR_URLBASE', "KeyfactorAPI"),
        "token": os.environ.get('KEYFACTOR_TOKEN', ""),
    }
scheme = config["scheme"]
host = config["host"]
URLBase = config["URLbase"]
token = config.get("token")
if not token:
    username = config.get("username")
    password = config.get("password")
    domain = config.get("domain")
    if username and password:
        username = format_username(username, domain)
    token = base64.b64encode(f"{username}:{password}".encode('utf-8')).decode('utf-8')

kfclient = keyfactorSDK.client.AuthenticatedClient(base_url=f"{scheme}://{host}/{URLBase}",
                                                   prefix="Basic", token=token, verify_ssl=True)


def delete_ca_(sync=True, **kwargs):
    if sync:
        return kf_delete_ca.sync(client=kfclient, **kwargs)


def get_ca_(sync=True, **kwargs):
    if sync:
        return kf_get_ca.sync(client=kfclient, **kwargs)


def update_ca_(sync=True, **kwargs):
    if sync:
        return kf_update_ca.sync(client=kfclient, **kwargs)


def create_ca_(sync=True, **kwargs):
    if sync:
        return kf_create_ca.sync(client=kfclient, **kwargs)


def publish_crl_(sync=True, **kwargs):
    if sync:
        return kf_publish_crl.sync(client=kfclient, **kwargs)


def get_cas_(sync=True, **kwargs):
    if sync:
        return kf_get_cas.sync(client=kfclient, **kwargs)


def test_certificate_authority_(sync=True, **kwargs):
    if sync:
        return kf_test_certificate_authority.sync(client=kfclient, **kwargs)


def delete_instance_(sync=True, **kwargs):
    if sync:
        return kf_delete_instance.sync(client=kfclient, **kwargs)


def query_instances_started_by_me_(sync=True, **kwargs):
    if sync:
        return kf_query_instances_started_by_me.sync(client=kfclient, **kwargs)


def restart_(sync=True, **kwargs):
    if sync:
        return kf_restart.sync(client=kfclient, **kwargs)


def query_(sync=True, **kwargs):
    if sync:
        return kf_query.sync(client=kfclient, **kwargs)


def get_(sync=True, **kwargs):
    if sync:
        return kf_get.sync(client=kfclient, **kwargs)


def stop_(sync=True, **kwargs):
    if sync:
        return kf_stop.sync(client=kfclient, **kwargs)


def query_instances_assigned_to_me_(sync=True, **kwargs):
    if sync:
        return kf_query_instances_assigned_to_me.sync(client=kfclient, **kwargs)


def signal_(sync=True, **kwargs):
    if sync:
        return kf_signal.sync(client=kfclient, **kwargs)


def get_collection_permissions_for_role_(sync=True, **kwargs):
    if sync:
        return kf_get_collection_permissions_for_role.sync(client=kfclient, **kwargs)


def get_permissions_for_role_(sync=True, **kwargs):
    if sync:
        return kf_get_permissions_for_role.sync(client=kfclient, **kwargs)


def set_container_permissions_(sync=True, **kwargs):
    if sync:
        return kf_set_container_permissions.sync(client=kfclient, **kwargs)


def add_global_permissions_(sync=True, **kwargs):
    if sync:
        return kf_add_global_permissions.sync(client=kfclient, **kwargs)


def get_global_permissions_for_role_(sync=True, **kwargs):
    if sync:
        return kf_get_global_permissions_for_role.sync(client=kfclient, **kwargs)


def add_collection_permissions_(sync=True, **kwargs):
    if sync:
        return kf_add_collection_permissions.sync(client=kfclient, **kwargs)


def set_collection_permissions_(sync=True, **kwargs):
    if sync:
        return kf_set_collection_permissions.sync(client=kfclient, **kwargs)


def get_container_permissions_for_role_(sync=True, **kwargs):
    if sync:
        return kf_get_container_permissions_for_role.sync(client=kfclient, **kwargs)


def set_global_permissions_(sync=True, **kwargs):
    if sync:
        return kf_set_global_permissions.sync(client=kfclient, **kwargs)


def add_container_permissions_(sync=True, **kwargs):
    if sync:
        return kf_add_container_permissions.sync(client=kfclient, **kwargs)


def delete_cs_rs_(sync=True, **kwargs):
    if sync:
        return kf_delete_cs_rs.sync(client=kfclient, **kwargs)


def get_pending_cs_rs_(sync=True, **kwargs):
    if sync:
        return kf_get_pending_cs_rs.sync(client=kfclient, **kwargs)


def post_generate_(sync=True, **kwargs):
    if sync:
        return kf_post_generate.sync(client=kfclient, **kwargs)


def delete_csr_(sync=True, **kwargs):
    if sync:
        return kf_delete_csr.sync(client=kfclient, **kwargs)


def download_(sync=True, **kwargs):
    if sync:
        return kf_download.sync(client=kfclient, **kwargs)


def create_logon_(sync=True, **kwargs):
    if sync:
        return kf_create_logon.sync(client=kfclient, **kwargs)


def query_logons_(sync=True, **kwargs):
    if sync:
        return kf_query_logons.sync(client=kfclient, **kwargs)


def delete_(sync=True, **kwargs):
    if sync:
        return kf_delete.sync(client=kfclient, **kwargs)


def get_logon_(sync=True, **kwargs):
    if sync:
        return kf_get_logon.sync(client=kfclient, **kwargs)


def logon_access_(sync=True, **kwargs):
    if sync:
        return kf_logon_access.sync(client=kfclient, **kwargs)


def add_expiration_alert_(sync=True, **kwargs):
    if sync:
        return kf_add_expiration_alert.sync(client=kfclient, **kwargs)


def delete_expiration_alert_(sync=True, **kwargs):
    if sync:
        return kf_delete_expiration_alert.sync(client=kfclient, **kwargs)


def get_expiration_alert_(sync=True, **kwargs):
    if sync:
        return kf_get_expiration_alert.sync(client=kfclient, **kwargs)


def get_schedule_(sync=True, **kwargs):
    if sync:
        return kf_get_schedule.sync(client=kfclient, **kwargs)


def edit_expiration_alert_(sync=True, **kwargs):
    if sync:
        return kf_edit_expiration_alert.sync(client=kfclient, **kwargs)


def test_expiration_alert_(sync=True, **kwargs):
    if sync:
        return kf_test_expiration_alert.sync(client=kfclient, **kwargs)


def get_expiration_alerts_(sync=True, **kwargs):
    if sync:
        return kf_get_expiration_alerts.sync(client=kfclient, **kwargs)


def edit_schedule_(sync=True, **kwargs):
    if sync:
        return kf_edit_schedule.sync(client=kfclient, **kwargs)


def test_all_expiration_alert_(sync=True, **kwargs):
    if sync:
        return kf_test_all_expiration_alert.sync(client=kfclient, **kwargs)


def rotate_service_account_key_(sync=True, **kwargs):
    if sync:
        return kf_rotate_service_account_key.sync(client=kfclient, **kwargs)


def delete_service_account_(sync=True, **kwargs):
    if sync:
        return kf_delete_service_account.sync(client=kfclient, **kwargs)


def delete_service_accounts_(sync=True, **kwargs):
    if sync:
        return kf_delete_service_accounts.sync(client=kfclient, **kwargs)


def create_service_account_(sync=True, **kwargs):
    if sync:
        return kf_create_service_account.sync(client=kfclient, **kwargs)


def query_service_accounts_(sync=True, **kwargs):
    if sync:
        return kf_query_service_accounts.sync(client=kfclient, **kwargs)


def update_service_account_(sync=True, **kwargs):
    if sync:
        return kf_update_service_account.sync(client=kfclient, **kwargs)


def get_(sync=True, **kwargs):
    if sync:
        return kf_get.sync(client=kfclient, **kwargs)


def get_service_account_key_(sync=True, **kwargs):
    if sync:
        return kf_get_service_account_key.sync(client=kfclient, **kwargs)


def get_audit_log_(sync=True, **kwargs):
    if sync:
        return kf_get_audit_log.sync(client=kfclient, **kwargs)


def get_audit_logs_(sync=True, **kwargs):
    if sync:
        return kf_get_audit_logs.sync(client=kfclient, **kwargs)


def validate_audit_log_(sync=True, **kwargs):
    if sync:
        return kf_validate_audit_log.sync(client=kfclient, **kwargs)


def download_csv_(sync=True, **kwargs):
    if sync:
        return kf_download_csv.sync(client=kfclient, **kwargs)


def get_related_entities_(sync=True, **kwargs):
    if sync:
        return kf_get_related_entities.sync(client=kfclient, **kwargs)


def get_job_history_(sync=True, **kwargs):
    if sync:
        return kf_get_job_history.sync(client=kfclient, **kwargs)


def unschedule_jobs_(sync=True, **kwargs):
    if sync:
        return kf_unschedule_jobs.sync(client=kfclient, **kwargs)


def schedule_bulk_job_(sync=True, **kwargs):
    if sync:
        return kf_schedule_bulk_job.sync(client=kfclient, **kwargs)


def get_scheduled_jobs_(sync=True, **kwargs):
    if sync:
        return kf_get_scheduled_jobs.sync(client=kfclient, **kwargs)


def reschedule_jobs_(sync=True, **kwargs):
    if sync:
        return kf_reschedule_jobs.sync(client=kfclient, **kwargs)


def get_custom_job_result_data_(sync=True, **kwargs):
    if sync:
        return kf_get_custom_job_result_data.sync(client=kfclient, **kwargs)


def schedule_job_(sync=True, **kwargs):
    if sync:
        return kf_schedule_job.sync(client=kfclient, **kwargs)


def acknowledge_jobs_(sync=True, **kwargs):
    if sync:
        return kf_acknowledge_jobs.sync(client=kfclient, **kwargs)


def update_certificate_store_server_(sync=True, **kwargs):
    if sync:
        return kf_update_certificate_store_server.sync(client=kfclient, **kwargs)


def schedule_(sync=True, **kwargs):
    if sync:
        return kf_schedule.sync(client=kfclient, **kwargs)


def get_certificate_store_inventory_(sync=True, **kwargs):
    if sync:
        return kf_get_certificate_store_inventory.sync(client=kfclient, **kwargs)


def configure_discovery_job_(sync=True, **kwargs):
    if sync:
        return kf_configure_discovery_job.sync(client=kfclient, **kwargs)


def delete_certificate_store_(sync=True, **kwargs):
    if sync:
        return kf_delete_certificate_store.sync(client=kfclient, **kwargs)


def set_password_(sync=True, **kwargs):
    if sync:
        return kf_set_password.sync(client=kfclient, **kwargs)


def approve_pending_(sync=True, **kwargs):
    if sync:
        return kf_approve_pending.sync(client=kfclient, **kwargs)


def create_certificate_store_server_(sync=True, **kwargs):
    if sync:
        return kf_create_certificate_store_server.sync(client=kfclient, **kwargs)


def add_certificate_(sync=True, **kwargs):
    if sync:
        return kf_add_certificate.sync(client=kfclient, **kwargs)


def schedule_for_reenrollment_(sync=True, **kwargs):
    if sync:
        return kf_schedule_for_reenrollment.sync(client=kfclient, **kwargs)


def remove_certificate_(sync=True, **kwargs):
    if sync:
        return kf_remove_certificate.sync(client=kfclient, **kwargs)


def delete_certificate_stores_(sync=True, **kwargs):
    if sync:
        return kf_delete_certificate_stores.sync(client=kfclient, **kwargs)


def edit_revocation_monitoring_(sync=True, **kwargs):
    if sync:
        return kf_edit_revocation_monitoring.sync(client=kfclient, **kwargs)


def add_revocation_monitoring_(sync=True, **kwargs):
    if sync:
        return kf_add_revocation_monitoring.sync(client=kfclient, **kwargs)


def delete_revocation_monitoring_(sync=True, **kwargs):
    if sync:
        return kf_delete_revocation_monitoring.sync(client=kfclient, **kwargs)


def get_revocation_monitoring_endpoints_(sync=True, **kwargs):
    if sync:
        return kf_get_revocation_monitoring_endpoints.sync(client=kfclient, **kwargs)


def get_revocation_monitoring_(sync=True, **kwargs):
    if sync:
        return kf_get_revocation_monitoring.sync(client=kfclient, **kwargs)


def resolve_ocsp_(sync=True, **kwargs):
    if sync:
        return kf_resolve_ocsp.sync(client=kfclient, **kwargs)


def test_revocation_monitoring_alert_(sync=True, **kwargs):
    if sync:
        return kf_test_revocation_monitoring_alert.sync(client=kfclient, **kwargs)


def test_all_revocation_monitoring_alert_(sync=True, **kwargs):
    if sync:
        return kf_test_all_revocation_monitoring_alert.sync(client=kfclient, **kwargs)


def add_access_(sync=True, **kwargs):
    if sync:
        return kf_add_access.sync(client=kfclient, **kwargs)


def create_server_(sync=True, **kwargs):
    if sync:
        return kf_create_server.sync(client=kfclient, **kwargs)


def get_(sync=True, **kwargs):
    if sync:
        return kf_get.sync(client=kfclient, **kwargs)


def query_servers_(sync=True, **kwargs):
    if sync:
        return kf_query_servers.sync(client=kfclient, **kwargs)


def remove_access_(sync=True, **kwargs):
    if sync:
        return kf_remove_access.sync(client=kfclient, **kwargs)


def delete_(sync=True, **kwargs):
    if sync:
        return kf_delete.sync(client=kfclient, **kwargs)


def get_access_(sync=True, **kwargs):
    if sync:
        return kf_get_access.sync(client=kfclient, **kwargs)


def update_server_(sync=True, **kwargs):
    if sync:
        return kf_update_server.sync(client=kfclient, **kwargs)


def get_endpoints_(sync=True, **kwargs):
    if sync:
        return kf_get_endpoints.sync(client=kfclient, **kwargs)


def get_agent_pools_(sync=True, **kwargs):
    if sync:
        return kf_get_agent_pools.sync(client=kfclient, **kwargs)


def get_default_agent_pool_agents_(sync=True, **kwargs):
    if sync:
        return kf_get_default_agent_pool_agents.sync(client=kfclient, **kwargs)


def get_agent_pool_by_id_(sync=True, **kwargs):
    if sync:
        return kf_get_agent_pool_by_id.sync(client=kfclient, **kwargs)


def create_agent_pool_(sync=True, **kwargs):
    if sync:
        return kf_create_agent_pool.sync(client=kfclient, **kwargs)


def delete_agent_pool_(sync=True, **kwargs):
    if sync:
        return kf_delete_agent_pool.sync(client=kfclient, **kwargs)


def update_agent_pool_(sync=True, **kwargs):
    if sync:
        return kf_update_agent_pool.sync(client=kfclient, **kwargs)


def renew_(sync=True, **kwargs):
    if sync:
        return kf_renew.sync(client=kfclient, **kwargs)


def install_pfx_to_cert_store_(sync=True, **kwargs):
    if sync:
        return kf_install_pfx_to_cert_store.sync(client=kfclient, **kwargs)


def add_to_existing_cert_stores_(sync=True, **kwargs):
    if sync:
        return kf_add_to_existing_cert_stores.sync(client=kfclient, **kwargs)


def get_my_pfx_context_(sync=True, **kwargs):
    if sync:
        return kf_get_my_pfx_context.sync(client=kfclient, **kwargs)


def available_renewal_id_(sync=True, **kwargs):
    if sync:
        return kf_available_renewal_id.sync(client=kfclient, **kwargs)


def get_template_enrollment_settings_(sync=True, **kwargs):
    if sync:
        return kf_get_template_enrollment_settings.sync(client=kfclient, **kwargs)


def get_my_csr_context_(sync=True, **kwargs):
    if sync:
        return kf_get_my_csr_context.sync(client=kfclient, **kwargs)


def post_csr_enroll_(sync=True, **kwargs):
    if sync:
        return kf_post_csr_enroll.sync(client=kfclient, **kwargs)


def post_parsed_csr_(sync=True, **kwargs):
    if sync:
        return kf_post_parsed_csr.sync(client=kfclient, **kwargs)


def post_pfx_enroll_(sync=True, **kwargs):
    if sync:
        return kf_post_pfx_enroll.sync(client=kfclient, **kwargs)


def available_renewal_thumbprint_(sync=True, **kwargs):
    if sync:
        return kf_available_renewal_thumbprint.sync(client=kfclient, **kwargs)


def revoke_(sync=True, **kwargs):
    if sync:
        return kf_revoke.sync(client=kfclient, **kwargs)


def update_metadata_(sync=True, **kwargs):
    if sync:
        return kf_update_metadata.sync(client=kfclient, **kwargs)


def delete_certificates_(sync=True, **kwargs):
    if sync:
        return kf_delete_certificates.sync(client=kfclient, **kwargs)


def get_certificate_security_(sync=True, **kwargs):
    if sync:
        return kf_get_certificate_security.sync(client=kfclient, **kwargs)


def download_certificate_async_(sync=True, **kwargs):
    if sync:
        return kf_download_certificate_async.sync(client=kfclient, **kwargs)


def validate_certificate_(sync=True, **kwargs):
    if sync:
        return kf_validate_certificate.sync(client=kfclient, **kwargs)


def certificate_history_(sync=True, **kwargs):
    if sync:
        return kf_certificate_history.sync(client=kfclient, **kwargs)


def update_all_metadata_(sync=True, **kwargs):
    if sync:
        return kf_update_all_metadata.sync(client=kfclient, **kwargs)


def recover_certificate_async_(sync=True, **kwargs):
    if sync:
        return kf_recover_certificate_async.sync(client=kfclient, **kwargs)


def revoke_all_(sync=True, **kwargs):
    if sync:
        return kf_revoke_all.sync(client=kfclient, **kwargs)


def delete_private_keys_0_(sync=True, **kwargs):
    if sync:
        return kf_delete_private_keys_0.sync(client=kfclient, **kwargs)


def delete_private_keys_1_(sync=True, **kwargs):
    if sync:
        return kf_delete_private_keys_1.sync(client=kfclient, **kwargs)


def query_certificates_(sync=True, **kwargs):
    if sync:
        return kf_query_certificates.sync(client=kfclient, **kwargs)


def delete_certificate_(sync=True, **kwargs):
    if sync:
        return kf_delete_certificate.sync(client=kfclient, **kwargs)


def compare_metadata_(sync=True, **kwargs):
    if sync:
        return kf_compare_metadata.sync(client=kfclient, **kwargs)


def post_import_certificate_(sync=True, **kwargs):
    if sync:
        return kf_post_import_certificate.sync(client=kfclient, **kwargs)


def get_certificate_(sync=True, **kwargs):
    if sync:
        return kf_get_certificate.sync(client=kfclient, **kwargs)


def delete_by_query_(sync=True, **kwargs):
    if sync:
        return kf_delete_by_query.sync(client=kfclient, **kwargs)


def analyze_cert_(sync=True, **kwargs):
    if sync:
        return kf_analyze_cert.sync(client=kfclient, **kwargs)


def identity_audit_(sync=True, **kwargs):
    if sync:
        return kf_identity_audit.sync(client=kfclient, **kwargs)


def get_certificate_locations_(sync=True, **kwargs):
    if sync:
        return kf_get_certificate_locations.sync(client=kfclient, **kwargs)


def get_templates_(sync=True, **kwargs):
    if sync:
        return kf_get_templates.sync(client=kfclient, **kwargs)


def get_valid_subject_parts_(sync=True, **kwargs):
    if sync:
        return kf_get_valid_subject_parts.sync(client=kfclient, **kwargs)


def update_global_settings_(sync=True, **kwargs):
    if sync:
        return kf_update_global_settings.sync(client=kfclient, **kwargs)


def update_template_(sync=True, **kwargs):
    if sync:
        return kf_update_template.sync(client=kfclient, **kwargs)


def get_global_settings_(sync=True, **kwargs):
    if sync:
        return kf_get_global_settings.sync(client=kfclient, **kwargs)


def get_template_(sync=True, **kwargs):
    if sync:
        return kf_get_template.sync(client=kfclient, **kwargs)


def template_import_(sync=True, **kwargs):
    if sync:
        return kf_import.sync(client=kfclient, **kwargs)


def update_collection_(sync=True, **kwargs):
    if sync:
        return kf_update_collection.sync(client=kfclient, **kwargs)


def get_collection_0_(sync=True, **kwargs):
    if sync:
        return kf_get_collection_0.sync(client=kfclient, **kwargs)


def set_collection_permissions_(sync=True, **kwargs):
    if sync:
        return kf_set_collection_permissions.sync(client=kfclient, **kwargs)


def create_collection_(sync=True, **kwargs):
    if sync:
        return kf_create_collection.sync(client=kfclient, **kwargs)


def copy_from_existing_collection_(sync=True, **kwargs):
    if sync:
        return kf_copy_from_existing_collection.sync(client=kfclient, **kwargs)


def get_collections_(sync=True, **kwargs):
    if sync:
        return kf_get_collections.sync(client=kfclient, **kwargs)


def get_collection_1_(sync=True, **kwargs):
    if sync:
        return kf_get_collection_1.sync(client=kfclient, **kwargs)


def get_identities_with_role_(sync=True, **kwargs):
    if sync:
        return kf_get_identities_with_role.sync(client=kfclient, **kwargs)


def delete_security_role_(sync=True, **kwargs):
    if sync:
        return kf_delete_security_role.sync(client=kfclient, **kwargs)


def update_identities_with_role_(sync=True, **kwargs):
    if sync:
        return kf_update_identities_with_role.sync(client=kfclient, **kwargs)


def add_access_(sync=True, **kwargs):
    if sync:
        return kf_add_access.sync(client=kfclient, **kwargs)


def get_group_(sync=True, **kwargs):
    if sync:
        return kf_get_group.sync(client=kfclient, **kwargs)


def get_group_by_name_(sync=True, **kwargs):
    if sync:
        return kf_get_group_by_name.sync(client=kfclient, **kwargs)


def update_server_group_(sync=True, **kwargs):
    if sync:
        return kf_update_server_group.sync(client=kfclient, **kwargs)


def remove_access_(sync=True, **kwargs):
    if sync:
        return kf_remove_access.sync(client=kfclient, **kwargs)


def delete_(sync=True, **kwargs):
    if sync:
        return kf_delete.sync(client=kfclient, **kwargs)


def get_access_(sync=True, **kwargs):
    if sync:
        return kf_get_access.sync(client=kfclient, **kwargs)


def create_server_group_(sync=True, **kwargs):
    if sync:
        return kf_create_server_group.sync(client=kfclient, **kwargs)


def query_server_groups_(sync=True, **kwargs):
    if sync:
        return kf_query_server_groups.sync(client=kfclient, **kwargs)


def update_report_schedule_(sync=True, **kwargs):
    if sync:
        return kf_update_report_schedule.sync(client=kfclient, **kwargs)


def delete_report_schedule_(sync=True, **kwargs):
    if sync:
        return kf_delete_report_schedule.sync(client=kfclient, **kwargs)


def update_report_parameters_(sync=True, **kwargs):
    if sync:
        return kf_update_report_parameters.sync(client=kfclient, **kwargs)


def update_custom_report_(sync=True, **kwargs):
    if sync:
        return kf_update_custom_report.sync(client=kfclient, **kwargs)


def query_reports_(sync=True, **kwargs):
    if sync:
        return kf_query_reports.sync(client=kfclient, **kwargs)


def query_custom_reports_(sync=True, **kwargs):
    if sync:
        return kf_query_custom_reports.sync(client=kfclient, **kwargs)


def get_report_parameters_(sync=True, **kwargs):
    if sync:
        return kf_get_report_parameters.sync(client=kfclient, **kwargs)


def get_report_schedule_(sync=True, **kwargs):
    if sync:
        return kf_get_report_schedule.sync(client=kfclient, **kwargs)


def update_report_(sync=True, **kwargs):
    if sync:
        return kf_update_report.sync(client=kfclient, **kwargs)


def get_report_schedules_(sync=True, **kwargs):
    if sync:
        return kf_get_report_schedules.sync(client=kfclient, **kwargs)


def get_report_(sync=True, **kwargs):
    if sync:
        return kf_get_report.sync(client=kfclient, **kwargs)


def get_custom_report_(sync=True, **kwargs):
    if sync:
        return kf_get_custom_report.sync(client=kfclient, **kwargs)


def create_report_schedule_(sync=True, **kwargs):
    if sync:
        return kf_create_report_schedule.sync(client=kfclient, **kwargs)


def delete_report_(sync=True, **kwargs):
    if sync:
        return kf_delete_report.sync(client=kfclient, **kwargs)


def create_custom_report_(sync=True, **kwargs):
    if sync:
        return kf_create_custom_report.sync(client=kfclient, **kwargs)


def get_all_certificate_store_containers_(sync=True, **kwargs):
    if sync:
        return kf_get_all_certificate_store_containers.sync(client=kfclient, **kwargs)


def delete_certificate_store_containers_(sync=True, **kwargs):
    if sync:
        return kf_delete_certificate_store_containers.sync(client=kfclient, **kwargs)


def delete_user_(sync=True, **kwargs):
    if sync:
        return kf_delete_user.sync(client=kfclient, **kwargs)


def query_users_(sync=True, **kwargs):
    if sync:
        return kf_query_users.sync(client=kfclient, **kwargs)


def get_user_(sync=True, **kwargs):
    if sync:
        return kf_get_user.sync(client=kfclient, **kwargs)


def create_user_(sync=True, **kwargs):
    if sync:
        return kf_create_user.sync(client=kfclient, **kwargs)


def update_user_(sync=True, **kwargs):
    if sync:
        return kf_update_user.sync(client=kfclient, **kwargs)


def user_access_(sync=True, **kwargs):
    if sync:
        return kf_user_access.sync(client=kfclient, **kwargs)


def delete_pam_provider_(sync=True, **kwargs):
    if sync:
        return kf_delete_pam_provider.sync(client=kfclient, **kwargs)


def create_pam_provider_type_(sync=True, **kwargs):
    if sync:
        return kf_create_pam_provider_type.sync(client=kfclient, **kwargs)


def get_metadata_field_in_use_(sync=True, **kwargs):
    if sync:
        return kf_get_metadata_field_in_use.sync(client=kfclient, **kwargs)


def delete_metadata_fields_(sync=True, **kwargs):
    if sync:
        return kf_delete_metadata_fields.sync(client=kfclient, **kwargs)


def get_metadata_field_0_(sync=True, **kwargs):
    if sync:
        return kf_get_metadata_field_0.sync(client=kfclient, **kwargs)


def create_metadata_field_(sync=True, **kwargs):
    if sync:
        return kf_create_metadata_field.sync(client=kfclient, **kwargs)


def get_metadata_field_1_(sync=True, **kwargs):
    if sync:
        return kf_get_metadata_field_1.sync(client=kfclient, **kwargs)


def get_all_metadata_fields_(sync=True, **kwargs):
    if sync:
        return kf_get_all_metadata_fields.sync(client=kfclient, **kwargs)


def update_metadata_field_(sync=True, **kwargs):
    if sync:
        return kf_update_metadata_field.sync(client=kfclient, **kwargs)


def delete_metadata_field_(sync=True, **kwargs):
    if sync:
        return kf_delete_metadata_field.sync(client=kfclient, **kwargs)


def delete_security_identity_(sync=True, **kwargs):
    if sync:
        return kf_delete_security_identity.sync(client=kfclient, **kwargs)


def identity_permissions_(sync=True, **kwargs):
    if sync:
        return kf_identity_permissions.sync(client=kfclient, **kwargs)


def lookup_identity_(sync=True, **kwargs):
    if sync:
        return kf_lookup_identity.sync(client=kfclient, **kwargs)


def deny_pending_requests_(sync=True, **kwargs):
    if sync:
        return kf_deny_pending_requests.sync(client=kfclient, **kwargs)


def get_(sync=True, **kwargs):
    if sync:
        return kf_get.sync(client=kfclient, **kwargs)


def approve_pending_requests_(sync=True, **kwargs):
    if sync:
        return kf_approve_pending_requests.sync(client=kfclient, **kwargs)


def get_certificate_request_details_(sync=True, **kwargs):
    if sync:
        return kf_get_certificate_request_details.sync(client=kfclient, **kwargs)


def get_denied_(sync=True, **kwargs):
    if sync:
        return kf_get_denied.sync(client=kfclient, **kwargs)


def get_denied_alert_(sync=True, **kwargs):
    if sync:
        return kf_get_denied_alert.sync(client=kfclient, **kwargs)


def delete_denied_alert_(sync=True, **kwargs):
    if sync:
        return kf_delete_denied_alert.sync(client=kfclient, **kwargs)


def get_denied_alerts_(sync=True, **kwargs):
    if sync:
        return kf_get_denied_alerts.sync(client=kfclient, **kwargs)


def edit_denied_alert_(sync=True, **kwargs):
    if sync:
        return kf_edit_denied_alert.sync(client=kfclient, **kwargs)


def add_denied_alert_(sync=True, **kwargs):
    if sync:
        return kf_add_denied_alert.sync(client=kfclient, **kwargs)


def get_issued_alerts_(sync=True, **kwargs):
    if sync:
        return kf_get_issued_alerts.sync(client=kfclient, **kwargs)


def add_issued_alert_(sync=True, **kwargs):
    if sync:
        return kf_add_issued_alert.sync(client=kfclient, **kwargs)


def edit_issued_alert_(sync=True, **kwargs):
    if sync:
        return kf_edit_issued_alert.sync(client=kfclient, **kwargs)


def get_schedule_(sync=True, **kwargs):
    if sync:
        return kf_get_schedule.sync(client=kfclient, **kwargs)


def edit_schedule_(sync=True, **kwargs):
    if sync:
        return kf_edit_schedule.sync(client=kfclient, **kwargs)


def get_issued_alert_(sync=True, **kwargs):
    if sync:
        return kf_get_issued_alert.sync(client=kfclient, **kwargs)


def delete_issued_alert_(sync=True, **kwargs):
    if sync:
        return kf_delete_issued_alert.sync(client=kfclient, **kwargs)


def get_agent_blueprints_(sync=True, **kwargs):
    if sync:
        return kf_get_agent_blueprints.sync(client=kfclient, **kwargs)


def apply_blueprint_(sync=True, **kwargs):
    if sync:
        return kf_apply_blueprint.sync(client=kfclient, **kwargs)


def delete_blueprint_(sync=True, **kwargs):
    if sync:
        return kf_delete_blueprint.sync(client=kfclient, **kwargs)


def get_blueprint_jobs_(sync=True, **kwargs):
    if sync:
        return kf_get_blueprint_jobs.sync(client=kfclient, **kwargs)


def get_agent_blueprint_(sync=True, **kwargs):
    if sync:
        return kf_get_agent_blueprint.sync(client=kfclient, **kwargs)


def generate_blueprint_(sync=True, **kwargs):
    if sync:
        return kf_generate_blueprint.sync(client=kfclient, **kwargs)


def get_blueprint_stores_(sync=True, **kwargs):
    if sync:
        return kf_get_blueprint_stores.sync(client=kfclient, **kwargs)


def set_network_ranges_(sync=True, **kwargs):
    if sync:
        return kf_set_network_ranges.sync(client=kfclient, **kwargs)


def network_scan_parts_(sync=True, **kwargs):
    if sync:
        return kf_network_scan_parts.sync(client=kfclient, **kwargs)


def validate_network_ranges_(sync=True, **kwargs):
    if sync:
        return kf_validate_network_ranges.sync(client=kfclient, **kwargs)


def update_network_(sync=True, **kwargs):
    if sync:
        return kf_update_network.sync(client=kfclient, **kwargs)


def results_(sync=True, **kwargs):
    if sync:
        return kf_results.sync(client=kfclient, **kwargs)


def add_network_ranges_(sync=True, **kwargs):
    if sync:
        return kf_add_network_ranges.sync(client=kfclient, **kwargs)


def endpoint_history_(sync=True, **kwargs):
    if sync:
        return kf_endpoint_history.sync(client=kfclient, **kwargs)


def get_network_(sync=True, **kwargs):
    if sync:
        return kf_get_network.sync(client=kfclient, **kwargs)


def get_networks_(sync=True, **kwargs):
    if sync:
        return kf_get_networks.sync(client=kfclient, **kwargs)


def create_network_(sync=True, **kwargs):
    if sync:
        return kf_create_network.sync(client=kfclient, **kwargs)


def get_network_ranges_for_network_(sync=True, **kwargs):
    if sync:
        return kf_get_network_ranges_for_network.sync(client=kfclient, **kwargs)


def monitoring_status_(sync=True, **kwargs):
    if sync:
        return kf_monitoring_status.sync(client=kfclient, **kwargs)


def scan_part_(sync=True, **kwargs):
    if sync:
        return kf_scan_part.sync(client=kfclient, **kwargs)


def monitor_all_(sync=True, **kwargs):
    if sync:
        return kf_monitor_all.sync(client=kfclient, **kwargs)


def review_all_(sync=True, **kwargs):
    if sync:
        return kf_review_all.sync(client=kfclient, **kwargs)


def remove_network_(sync=True, **kwargs):
    if sync:
        return kf_remove_network.sync(client=kfclient, **kwargs)


def remove_all_network_ranges_(sync=True, **kwargs):
    if sync:
        return kf_remove_all_network_ranges.sync(client=kfclient, **kwargs)


def immediate_ssl_scan_(sync=True, **kwargs):
    if sync:
        return kf_immediate_ssl_scan.sync(client=kfclient, **kwargs)


def endpoint_(sync=True, **kwargs):
    if sync:
        return kf_endpoint.sync(client=kfclient, **kwargs)


def reviewed_status_(sync=True, **kwargs):
    if sync:
        return kf_reviewed_status.sync(client=kfclient, **kwargs)


def update_job_type_(sync=True, **kwargs):
    if sync:
        return kf_update_job_type.sync(client=kfclient, **kwargs)


def delete_job_type_(sync=True, **kwargs):
    if sync:
        return kf_delete_job_type.sync(client=kfclient, **kwargs)


def get_job_type_by_id_(sync=True, **kwargs):
    if sync:
        return kf_get_job_type_by_id.sync(client=kfclient, **kwargs)


def get_job_types_(sync=True, **kwargs):
    if sync:
        return kf_get_job_types.sync(client=kfclient, **kwargs)


def create_job_type_(sync=True, **kwargs):
    if sync:
        return kf_create_job_type.sync(client=kfclient, **kwargs)


def get_agents_(sync=True, **kwargs):
    if sync:
        return kf_get_agents.sync(client=kfclient, **kwargs)


def reset_1_(sync=True, **kwargs):
    if sync:
        return kf_reset_1.sync(client=kfclient, **kwargs)


def approve_(sync=True, **kwargs):
    if sync:
        return kf_approve.sync(client=kfclient, **kwargs)


def set_auth_certificate_reenrollment_(sync=True, **kwargs):
    if sync:
        return kf_set_auth_certificate_reenrollment.sync(client=kfclient, **kwargs)


def disapprove_(sync=True, **kwargs):
    if sync:
        return kf_disapprove.sync(client=kfclient, **kwargs)


def fetch_logs_(sync=True, **kwargs):
    if sync:
        return kf_fetch_logs.sync(client=kfclient, **kwargs)


def get_agent_detail_(sync=True, **kwargs):
    if sync:
        return kf_get_agent_detail.sync(client=kfclient, **kwargs)


def reset_0_(sync=True, **kwargs):
    if sync:
        return kf_reset_0.sync(client=kfclient, **kwargs)


def edit_pending_alert_(sync=True, **kwargs):
    if sync:
        return kf_edit_pending_alert.sync(client=kfclient, **kwargs)


def test_all_pending_alert_(sync=True, **kwargs):
    if sync:
        return kf_test_all_pending_alert.sync(client=kfclient, **kwargs)


def test_pending_alert_(sync=True, **kwargs):
    if sync:
        return kf_test_pending_alert.sync(client=kfclient, **kwargs)


def get_schedule_(sync=True, **kwargs):
    if sync:
        return kf_get_schedule.sync(client=kfclient, **kwargs)


def delete_pending_alert_(sync=True, **kwargs):
    if sync:
        return kf_delete_pending_alert.sync(client=kfclient, **kwargs)


def get_pending_alerts_(sync=True, **kwargs):
    if sync:
        return kf_get_pending_alerts.sync(client=kfclient, **kwargs)


def get_pending_alert_(sync=True, **kwargs):
    if sync:
        return kf_get_pending_alert.sync(client=kfclient, **kwargs)


def add_pending_alert_(sync=True, **kwargs):
    if sync:
        return kf_add_pending_alert.sync(client=kfclient, **kwargs)


def edit_schedule_(sync=True, **kwargs):
    if sync:
        return kf_edit_schedule.sync(client=kfclient, **kwargs)


def et_current_license_(sync=True, **kwargs):
    if sync:
        return kf_et_current_license.sync(client=kfclient, **kwargs)


def edit_mac_enrollment_(sync=True, **kwargs):
    if sync:
        return kf_edit_mac_enrollment.sync(client=kfclient, **kwargs)


def mac_enrollment_(sync=True, **kwargs):
    if sync:
        return kf_mac_enrollment.sync(client=kfclient, **kwargs)


def publish_definition_(sync=True, **kwargs):
    if sync:
        return kf_publish_definition.sync(client=kfclient, **kwargs)


def query_(sync=True, **kwargs):
    if sync:
        return kf_query.sync(client=kfclient, **kwargs)


def get_(sync=True, **kwargs):
    if sync:
        return kf_get.sync(client=kfclient, **kwargs)


def configure_definition_steps_(sync=True, **kwargs):
    if sync:
        return kf_configure_definition_steps.sync(client=kfclient, **kwargs)


def query_workflow_types_(sync=True, **kwargs):
    if sync:
        return kf_query_workflow_types.sync(client=kfclient, **kwargs)


def update_existing_definition_(sync=True, **kwargs):
    if sync:
        return kf_update_existing_definition.sync(client=kfclient, **kwargs)


def get_step_schema_(sync=True, **kwargs):
    if sync:
        return kf_get_step_schema.sync(client=kfclient, **kwargs)


def query_available_steps_(sync=True, **kwargs):
    if sync:
        return kf_query_available_steps.sync(client=kfclient, **kwargs)


def create_new_definition_(sync=True, **kwargs):
    if sync:
        return kf_create_new_definition.sync(client=kfclient, **kwargs)


def delete_(sync=True, **kwargs):
    if sync:
        return kf_delete.sync(client=kfclient, **kwargs)


def add_key_rotation_alert_(sync=True, **kwargs):
    if sync:
        return kf_add_key_rotation_alert.sync(client=kfclient, **kwargs)


def test_all_key_rotation_alert_(sync=True, **kwargs):
    if sync:
        return kf_test_all_key_rotation_alert.sync(client=kfclient, **kwargs)


def get_key_rotation_alerts_(sync=True, **kwargs):
    if sync:
        return kf_get_key_rotation_alerts.sync(client=kfclient, **kwargs)


def get_schedule_(sync=True, **kwargs):
    if sync:
        return kf_get_schedule.sync(client=kfclient, **kwargs)


def delete_key_rotation_alert_(sync=True, **kwargs):
    if sync:
        return kf_delete_key_rotation_alert.sync(client=kfclient, **kwargs)


def edit_schedule_(sync=True, **kwargs):
    if sync:
        return kf_edit_schedule.sync(client=kfclient, **kwargs)


def get_key_rotation_alert_(sync=True, **kwargs):
    if sync:
        return kf_get_key_rotation_alert.sync(client=kfclient, **kwargs)


def test_key_rotation_alert_(sync=True, **kwargs):
    if sync:
        return kf_test_key_rotation_alert.sync(client=kfclient, **kwargs)


def edit_key_rotation_alert_(sync=True, **kwargs):
    if sync:
        return kf_edit_key_rotation_alert.sync(client=kfclient, **kwargs)


def get_unmanaged_keys_(sync=True, **kwargs):
    if sync:
        return kf_get_unmanaged_keys.sync(client=kfclient, **kwargs)


def get_unmanaged_key_(sync=True, **kwargs):
    if sync:
        return kf_get_unmanaged_key.sync(client=kfclient, **kwargs)


def update_(sync=True, **kwargs):
    if sync:
        return kf_update.sync(client=kfclient, **kwargs)


def delete_unmanaged_keys_(sync=True, **kwargs):
    if sync:
        return kf_delete_unmanaged_keys.sync(client=kfclient, **kwargs)


def generate_key_(sync=True, **kwargs):
    if sync:
        return kf_generate_key.sync(client=kfclient, **kwargs)


def delete_unmanaged_key_(sync=True, **kwargs):
    if sync:
        return kf_delete_unmanaged_key.sync(client=kfclient, **kwargs)


def get_my_key_(sync=True, **kwargs):
    if sync:
        return kf_get_my_key.sync(client=kfclient, **kwargs)


def smtp_(sync=True, **kwargs):
    if sync:
        return kf_smtp.sync(client=kfclient, **kwargs)


def update_smtp_(sync=True, **kwargs):
    if sync:
        return kf_update_smtp.sync(client=kfclient, **kwargs)


def test_smtp_(sync=True, **kwargs):
    if sync:
        return kf_test_smtp.sync(client=kfclient, **kwargs)


def get_certificate_store_type_0_(sync=True, **kwargs):
    if sync:
        return kf_get_certificate_store_type_0.sync(client=kfclient, **kwargs)


def delete_certificate_store_types_(sync=True, **kwargs):
    if sync:
        return kf_delete_certificate_store_types.sync(client=kfclient, **kwargs)


def delete_certificate_store_type_(sync=True, **kwargs):
    if sync:
        return kf_delete_certificate_store_type.sync(client=kfclient, **kwargs)


def update_certificate_store_type_(sync=True, **kwargs):
    if sync:
        return kf_update_certificate_store_type.sync(client=kfclient, **kwargs)


def get_certificate_store_type_1_(sync=True, **kwargs):
    if sync:
        return kf_get_certificate_store_type_1.sync(client=kfclient, **kwargs)


def create_certificate_store_type_(sync=True, **kwargs):
    if sync:
        return kf_create_certificate_store_type.sync(client=kfclient, **kwargs)


def get_types_(sync=True, **kwargs):
    if sync:
        return kf_get_types.sync(client=kfclient, **kwargs)


def update_ca(args):
    return normalize(update_ca_(
        json_body=kf_models_certificate_authorities_certificate_authority_request.ModelsCertificateAuthoritiesCertificateAuthorityRequest.from_dict(
            args)))


def create_ca(args):
    return normalize(create_ca_(
        json_body=kf_models_certificate_authorities_certificate_authority_request.ModelsCertificateAuthoritiesCertificateAuthorityRequest.from_dict(
            args)))


def publish_crl(args):
    return normalize(
        publish_crl_(json_body=kf_models_crl_request_model.ModelsCRLRequestModel.from_dict(args)))


def test_certificate_authority(args):
    return normalize(test_certificate_authority_(
        json_body=kf_models_certificate_authorities_certificate_authority_request.ModelsCertificateAuthoritiesCertificateAuthorityRequest.from_dict(
            args)))


def signal(args):
    return normalize(signal_(
        json_body=kf_keyfactor_api_models_workflows_signal_request.KeyfactorApiModelsWorkflowsSignalRequest.from_dict(
            args)))


def generate(args):
    return normalize(post_generate_(
        json_body=kf_models_enrollment_csr_generation_request.ModelsEnrollmentCSRGenerationRequest.from_dict(
            args)))


def create_logon(args):
    return normalize(create_logon_(
        json_body=kf_models_ssh_logons_logon_creation_request.ModelsSSHLogonsLogonCreationRequest.from_dict(
            args)))


def logon_access(args):
    return normalize(logon_access_(
        json_body=kf_models_ssh_logons_logon_access_request.ModelsSSHLogonsLogonAccessRequest.from_dict(
            args)))


def add_expiration_alert(args):
    return normalize(add_expiration_alert_(
        json_body=kf_keyfactor_api_models_alerts_expiration_expiration_alert_creation_request.KeyfactorApiModelsAlertsExpirationExpirationAlertCreationRequest.from_dict(
            args)))


def edit_expiration_alert(args):
    return normalize(edit_expiration_alert_(
        json_body=kf_keyfactor_api_models_alerts_expiration_expiration_alert_update_request.KeyfactorApiModelsAlertsExpirationExpirationAlertUpdateRequest.from_dict(
            args)))


def test_expiration_alert(args):
    return normalize(test_expiration_alert_(
        json_body=kf_keyfactor_api_models_alerts_expiration_expiration_alert_test_request.KeyfactorApiModelsAlertsExpirationExpirationAlertTestRequest.from_dict(
            args)))


def edit_schedule(args):
    return normalize(edit_schedule_(
        json_body=kf_keyfactor_api_models_alerts_alert_schedule_alert_schedule_request.KeyfactorApiModelsAlertsAlertScheduleAlertScheduleRequest.from_dict(
            args)))


def test_all_expiration_alert(args):
    return normalize(test_all_expiration_alert_(
        json_body=kf_keyfactor_api_models_alerts_expiration_expiration_alert_test_all_request.KeyfactorApiModelsAlertsExpirationExpirationAlertTestAllRequest.from_dict(
            args)))


def rotate_service_account_key(args):
    return normalize(rotate_service_account_key_(
        json_body=kf_models_ssh_keys_key_generation_request.ModelsSSHKeysKeyGenerationRequest.from_dict(
            args)))


def create_service_account(args):
    return normalize(create_service_account_(
        json_body=kf_models_ssh_service_accounts_service_account_creation_request.ModelsSSHServiceAccountsServiceAccountCreationRequest.from_dict(
            args)))


def update_service_account(args):
    return normalize(update_service_account_(
        json_body=kf_models_ssh_service_accounts_service_account_update_request.ModelsSSHServiceAccountsServiceAccountUpdateRequest.from_dict(
            args)))


def unschedule_jobs(args):
    return normalize(unschedule_jobs_(
        json_body=kf_keyfactor_api_models_orchestrator_jobs_unschedule_job_request.KeyfactorApiModelsOrchestratorJobsUnscheduleJobRequest.from_dict(
            args)))


def schedule_bulk_job(args):
    return normalize(schedule_bulk_job_(
        json_body=kf_models_orchestrator_jobs_schedule_bulk_job_request.ModelsOrchestratorJobsScheduleBulkJobRequest.from_dict(
            args)))


def reschedule_jobs(args):
    return normalize(reschedule_jobs_(
        json_body=kf_keyfactor_api_models_orchestrator_jobs_reschedule_job_request.KeyfactorApiModelsOrchestratorJobsRescheduleJobRequest.from_dict(
            args)))


def schedule_job(args):
    return normalize(schedule_job_(
        json_body=kf_models_orchestrator_jobs_schedule_job_request.ModelsOrchestratorJobsScheduleJobRequest.from_dict(
            args)))


def acknowledge_jobs(args):
    return normalize(acknowledge_jobs_(
        json_body=kf_keyfactor_api_models_orchestrator_jobs_acknowledge_job_request.KeyfactorApiModelsOrchestratorJobsAcknowledgeJobRequest.from_dict(
            args)))


def update_certificate_store_server(args):
    return normalize(update_certificate_store_server_(
        json_body=kf_models_certificate_store_update_server_request.ModelsCertificateStoreUpdateServerRequest.from_dict(
            args)))


def schedule(args):
    return normalize(schedule_(
        json_body=kf_models_cert_stores_schedule.ModelsCertStoresSchedule.from_dict(args)))


def configure_discovery_job(args):
    return normalize(configure_discovery_job_(
        json_body=kf_models_discovery_job_request.ModelsDiscoveryJobRequest.from_dict(args)))


def set_password(args):
    return normalize(set_password_(
        json_body=kf_models_cert_store_new_password_request.ModelsCertStoreNewPasswordRequest.from_dict(
            args)))


def create_certificate_store_server(args):
    return normalize(create_certificate_store_server_(
        json_body=kf_models_certificate_store_create_server_request.ModelsCertificateStoreCreateServerRequest.from_dict(
            args)))


def add_certificate(args):
    return normalize(add_certificate_(
        json_body=kf_keyfactor_api_models_certificate_stores_add_certificate_request.KeyfactorApiModelsCertificateStoresAddCertificateRequest.from_dict(
            args)))


def schedule_for_reenrollment(args):
    return normalize(schedule_for_reenrollment_(
        json_body=kf_keyfactor_api_models_certificate_stores_reenrollment_request.KeyfactorApiModelsCertificateStoresReenrollmentRequest.from_dict(
            args)))


def remove_certificate(args):
    return normalize(remove_certificate_(
        json_body=kf_keyfactor_api_models_certificate_stores_remove_certificate_request.KeyfactorApiModelsCertificateStoresRemoveCertificateRequest.from_dict(
            args)))


def edit_revocation_monitoring(args):
    return normalize(edit_revocation_monitoring_(
        json_body=kf_keyfactor_api_models_monitoring_revocation_monitoring_update_request.KeyfactorApiModelsMonitoringRevocationMonitoringUpdateRequest.from_dict(
            args)))


def add_revocation_monitoring(args):
    return normalize(add_revocation_monitoring_(
        json_body=kf_keyfactor_api_models_monitoring_revocation_monitoring_creation_request.KeyfactorApiModelsMonitoringRevocationMonitoringCreationRequest.from_dict(
            args)))


def resolve_ocsp(args):
    return normalize(resolve_ocsp_(
        json_body=kf_keyfactor_api_models_monitoring_ocsp_parameters_request.KeyfactorApiModelsMonitoringOCSPParametersRequest.from_dict(
            args)))


def test_revocation_monitoring_alert(args):
    return normalize(test_revocation_monitoring_alert_(
        json_body=kf_keyfactor_api_models_monitoring_revocation_monitoring_alert_test_request.KeyfactorApiModelsMonitoringRevocationMonitoringAlertTestRequest.from_dict(
            args)))


def test_all_revocation_monitoring_alert(args):
    return normalize(test_all_revocation_monitoring_alert_(
        json_body=kf_keyfactor_api_models_monitoring_revocation_monitoring_alert_test_all_request.KeyfactorApiModelsMonitoringRevocationMonitoringAlertTestAllRequest.from_dict(
            args)))


def add_access(args):
    return normalize(add_access_(
        json_body=kf_models_ssh_access_server_group_access_request.ModelsSSHAccessServerGroupAccessRequest.from_dict(
            args)))


def create_server(args):
    return normalize(create_server_(
        json_body=kf_models_ssh_servers_server_creation_request.ModelsSSHServersServerCreationRequest.from_dict(
            args)))


def remove_access(args):
    return normalize(remove_access_(
        json_body=kf_models_ssh_access_server_group_access_request.ModelsSSHAccessServerGroupAccessRequest.from_dict(
            args)))


def update_server(args):
    return normalize(update_server_(
        json_body=kf_models_ssh_servers_server_update_request.ModelsSSHServersServerUpdateRequest.from_dict(
            args)))


def create_agent_pool(args):
    return normalize(create_agent_pool_(
        json_body=kf_models_agents_agent_pool.ModelsAgentsAgentPool.from_dict(args)))


def update_agent_pool(args):
    return normalize(update_agent_pool_(
        json_body=kf_models_agents_agent_pool.ModelsAgentsAgentPool.from_dict(args)))


def renew(args):
    args["Timestamp"] = datetime.utcnow().isoformat(timespec="seconds") + "+00:00"
    return normalize(renew_(
        json_body=kf_models_enrollment_renewal_request.ModelsEnrollmentRenewalRequest.from_dict(
            args)))


def install_pfx_to_cert_store(args):
    return normalize(install_pfx_to_cert_store_(
        json_body=kf_keyfactor_api_models_enrollment_enrollment_management_request.KeyfactorApiModelsEnrollmentEnrollmentManagementRequest.from_dict(
            args)))


def add_to_existing_cert_stores(args):
    return normalize(add_to_existing_cert_stores_(
        json_body=kf_models_enrollment_existing_enrollment_management_request.ModelsEnrollmentExistingEnrollmentManagementRequest.from_dict(
            args)))


def csr_enroll(args):
    args["Timestamp"] = datetime.utcnow().isoformat(timespec="seconds") + "+00:00"
    return normalize(post_csr_enroll_(
        json_body=kf_models_enrollment_csr_enrollment_request.ModelsEnrollmentCSREnrollmentRequest.from_dict(
            args)))


def parsed_csr(args):
    return normalize(
        post_parsed_csr_(json_body=kf_models_csr_contents.ModelsCSRContents.from_dict(args)))


def pfx_enroll(args):
    args["Timestamp"] = datetime.utcnow().isoformat(timespec="seconds") + "+00:00"
    return normalize(post_pfx_enroll_(
        json_body=kf_models_enrollment_pfx_enrollment_request.ModelsEnrollmentPFXEnrollmentRequest.from_dict(
            args)))


def revoke(args):
    return normalize(revoke_(
        json_body=kf_models_revoke_certificate_request.ModelsRevokeCertificateRequest.from_dict(
            args)))


def update_metadata(args):
    return normalize(update_metadata_(
        json_body=kf_models_metadata_update_request.ModelsMetadataUpdateRequest.from_dict(args)))


def download_certificate_async(args):
    return normalize(download_certificate_async_(
        json_body=kf_models_certificate_download_request.ModelsCertificateDownloadRequest.from_dict(
            args)))


def update_all_metadata(args):
    return normalize(update_all_metadata_(
        json_body=kf_models_metadata_all_update_request.ModelsMetadataAllUpdateRequest.from_dict(
            args)))


def recover_certificate_async(args):
    return normalize(recover_certificate_async_(
        json_body=kf_models_certificate_recovery_request.ModelsCertificateRecoveryRequest.from_dict(
            args)))


def revoke_all(args):
    return normalize(revoke_all_(
        json_body=kf_models_revoke_all_certificates_request.ModelsRevokeAllCertificatesRequest.from_dict(
            args)))


def template_import_certificate(args):
    return normalize(post_import_certificate_(
        json_body=kf_models_certificate_import_request_model.ModelsCertificateImportRequestModel.from_dict(
            args)))


def analyze_cert(args):
    return normalize(analyze_cert_(
        json_body=kf_keyfactor_api_models_certificates_analyze_certificate_request.KeyfactorApiModelsCertificatesAnalyzeCertificateRequest.from_dict(
            args)))


def update_global_settings(args):
    return normalize(update_global_settings_(
        json_body=kf_keyfactor_api_models_templates_global_template_settings_request.KeyfactorApiModelsTemplatesGlobalTemplateSettingsRequest.from_dict(
            args)))


def update_template(args):
    return normalize(update_template_(
        json_body=kf_models_template_update_request.ModelsTemplateUpdateRequest.from_dict(args)))


def template_import(args):
    return normalize(template_import_(
        json_body=kf_keyfactor_api_models_configuration_tenant_configuration_tenant_request.KeyfactorApiModelsConfigurationTenantConfigurationTenantRequest.from_dict(
            args)))


def update_collection(args):
    return normalize(update_collection_(
        json_body=kf_keyfactor_api_models_certificate_collections_certificate_collection_update_request.KeyfactorApiModelsCertificateCollectionsCertificateCollectionUpdateRequest.from_dict(
            args)))


def create_collection(args):
    return normalize(create_collection_(
        json_body=kf_keyfactor_api_models_certificate_collections_certificate_collection_create_request.KeyfactorApiModelsCertificateCollectionsCertificateCollectionCreateRequest.from_dict(
            args)))


def copy_from_existing_collection(args):
    return normalize(copy_from_existing_collection_(
        json_body=kf_keyfactor_api_models_certificate_collections_certificate_collection_copy_request.KeyfactorApiModelsCertificateCollectionsCertificateCollectionCopyRequest.from_dict(
            args)))


def update_identities_with_role(args):
    return normalize(update_identities_with_role_(
        json_body=kf_keyfactor_api_models_security_roles_role_identities_request.KeyfactorApiModelsSecurityRolesRoleIdentitiesRequest.from_dict(
            args)))


def update_server_group(args):
    return normalize(update_server_group_(
        json_body=kf_models_ssh_server_groups_server_group_update_request.ModelsSSHServerGroupsServerGroupUpdateRequest.from_dict(
            args)))


def create_server_group(args):
    return normalize(create_server_group_(
        json_body=kf_models_ssh_server_groups_server_group_creation_request.ModelsSSHServerGroupsServerGroupCreationRequest.from_dict(
            args)))


def update_report_schedule(args):
    return normalize(update_report_schedule_(
        json_body=kf_models_report_schedule.ModelsReportSchedule.from_dict(args)))


def update_custom_report(args):
    return normalize(update_custom_report_(
        json_body=kf_models_custom_report_update_request.ModelsCustomReportUpdateRequest.from_dict(
            args)))


def update_report(args):
    return normalize(update_report_(
        json_body=kf_models_report_request_model.ModelsReportRequestModel.from_dict(args)))


def create_report_schedule(args):
    return normalize(create_report_schedule_(
        json_body=kf_models_report_schedule.ModelsReportSchedule.from_dict(args)))


def create_custom_report(args):
    return normalize(create_custom_report_(
        json_body=kf_models_custom_report_creation_request.ModelsCustomReportCreationRequest.from_dict(
            args)))


def create_user(args):
    return normalize(create_user_(
        json_body=kf_models_ssh_users_ssh_user_creation_request.ModelsSSHUsersSshUserCreationRequest.from_dict(
            args)))


def update_user(args):
    return normalize(update_user_(
        json_body=kf_models_ssh_users_ssh_user_update_request.ModelsSSHUsersSshUserUpdateRequest.from_dict(
            args)))


def user_access(args):
    return normalize(user_access_(
        json_body=kf_models_ssh_users_ssh_user_update_request.ModelsSSHUsersSshUserUpdateRequest.from_dict(
            args)))


def create_pam_provider_type(args):
    return normalize(create_pam_provider_type_(
        json_body=kf_keyfactor_api_pam_provider_type_create_request.KeyfactorApiPAMProviderTypeCreateRequest.from_dict(
            args)))


def create_metadata_field(args):
    return normalize(create_metadata_field_(
        json_body=kf_keyfactor_api_models_metadata_field_metadata_field_create_request.KeyfactorApiModelsMetadataFieldMetadataFieldCreateRequest.from_dict(
            args)))


def update_metadata_field(args):
    return normalize(update_metadata_field_(
        json_body=kf_keyfactor_api_models_metadata_field_metadata_field_update_request.KeyfactorApiModelsMetadataFieldMetadataFieldUpdateRequest.from_dict(
            args)))


def deny_pending_requests(args):
    return normalize(deny_pending_requests_(
        json_body=kf_models_workflow_denial_request.ModelsWorkflowDenialRequest.from_dict(args)))


def edit_denied_alert(args):
    return normalize(edit_denied_alert_(
        json_body=kf_keyfactor_api_models_alerts_denied_denied_alert_update_request.KeyfactorApiModelsAlertsDeniedDeniedAlertUpdateRequest.from_dict(
            args)))


def add_denied_alert(args):
    return normalize(add_denied_alert_(
        json_body=kf_keyfactor_api_models_alerts_denied_denied_alert_creation_request.KeyfactorApiModelsAlertsDeniedDeniedAlertCreationRequest.from_dict(
            args)))


def add_issued_alert(args):
    return normalize(add_issued_alert_(
        json_body=kf_keyfactor_api_models_alerts_issued_issued_alert_creation_request.KeyfactorApiModelsAlertsIssuedIssuedAlertCreationRequest.from_dict(
            args)))


def edit_issued_alert(args):
    return normalize(edit_issued_alert_(
        json_body=kf_keyfactor_api_models_alerts_issued_issued_alert_update_request.KeyfactorApiModelsAlertsIssuedIssuedAlertUpdateRequest.from_dict(
            args)))


def set_network_ranges(args):
    return normalize(set_network_ranges_(
        json_body=kf_models_ssl_network_ranges_request.ModelsSSLNetworkRangesRequest.from_dict(
            args)))


def update_network(args):
    return normalize(update_network_(
        json_body=kf_keyfactor_api_models_ssl_update_network_request.KeyfactorApiModelsSslUpdateNetworkRequest.from_dict(
            args)))


def add_network_ranges(args):
    return normalize(add_network_ranges_(
        json_body=kf_models_ssl_network_ranges_request.ModelsSSLNetworkRangesRequest.from_dict(
            args)))


def create_network(args):
    return normalize(create_network_(
        json_body=kf_keyfactor_api_models_ssl_create_network_request.KeyfactorApiModelsSslCreateNetworkRequest.from_dict(
            args)))


def immediate_ssl_scan(args):
    return normalize(immediate_ssl_scan_(
        json_body=kf_models_ssl_immediate_ssl_scan_request.ModelsSSLImmediateSslScanRequest.from_dict(
            args)))


def update_job_type(args):
    return normalize(update_job_type_(
        json_body=kf_models_orchestrator_jobs_job_type_update_request.ModelsOrchestratorJobsJobTypeUpdateRequest.from_dict(
            args)))


def create_job_type(args):
    return normalize(create_job_type_(
        json_body=kf_models_orchestrator_jobs_job_type_create_request.ModelsOrchestratorJobsJobTypeCreateRequest.from_dict(
            args)))


def set_auth_certificate_reenrollment(args):
    return normalize(set_auth_certificate_reenrollment_(
        json_body=kf_keyfactor_api_models_orchestrators_update_orchestrator_auth_certificate_reenrollment_request.KeyfactorApiModelsOrchestratorsUpdateOrchestratorAuthCertificateReenrollmentRequest.from_dict(
            args)))


def edit_pending_alert(args):
    return normalize(edit_pending_alert_(
        json_body=kf_keyfactor_api_models_alerts_pending_pending_alert_update_request.KeyfactorApiModelsAlertsPendingPendingAlertUpdateRequest.from_dict(
            args)))


def test_all_pending_alert(args):
    return normalize(test_all_pending_alert_(
        json_body=kf_keyfactor_api_models_alerts_pending_pending_alert_test_all_request.KeyfactorApiModelsAlertsPendingPendingAlertTestAllRequest.from_dict(
            args)))


def test_pending_alert(args):
    return normalize(test_pending_alert_(
        json_body=kf_keyfactor_api_models_alerts_pending_pending_alert_test_request.KeyfactorApiModelsAlertsPendingPendingAlertTestRequest.from_dict(
            args)))


def add_pending_alert(args):
    return normalize(add_pending_alert_(
        json_body=kf_keyfactor_api_models_alerts_pending_pending_alert_creation_request.KeyfactorApiModelsAlertsPendingPendingAlertCreationRequest.from_dict(
            args)))


def edit_mac_enrollment(args):
    return normalize(edit_mac_enrollment_(
        json_body=kf_keyfactor_api_models_mac_enrollment_mac_enrollment_api_model.KeyfactorApiModelsMacEnrollmentMacEnrollmentAPIModel.from_dict(
            args)))


def update_existing_definition(args):
    return normalize(update_existing_definition_(
        json_body=kf_keyfactor_api_models_workflows_definition_update_request.KeyfactorApiModelsWorkflowsDefinitionUpdateRequest.from_dict(
            args)))


def create_new_definition(args):
    return normalize(create_new_definition_(
        json_body=kf_keyfactor_api_models_workflows_definition_create_request.KeyfactorApiModelsWorkflowsDefinitionCreateRequest.from_dict(
            args)))


def add_key_rotation_alert(args):
    return normalize(add_key_rotation_alert_(
        json_body=kf_keyfactor_api_models_alerts_key_rotation_key_rotation_alert_creation_request.KeyfactorApiModelsAlertsKeyRotationKeyRotationAlertCreationRequest.from_dict(
            args)))


def test_all_key_rotation_alert(args):
    return normalize(test_all_key_rotation_alert_(
        json_body=kf_keyfactor_api_models_alerts_key_rotation_key_rotation_alert_test_all_request.KeyfactorApiModelsAlertsKeyRotationKeyRotationAlertTestAllRequest.from_dict(
            args)))


def test_key_rotation_alert(args):
    return normalize(test_key_rotation_alert_(
        json_body=kf_keyfactor_api_models_alerts_key_rotation_key_rotation_alert_test_request.KeyfactorApiModelsAlertsKeyRotationKeyRotationAlertTestRequest.from_dict(
            args)))


def edit_key_rotation_alert(args):
    return normalize(edit_key_rotation_alert_(
        json_body=kf_keyfactor_api_models_alerts_key_rotation_key_rotation_alert_update_request.KeyfactorApiModelsAlertsKeyRotationKeyRotationAlertUpdateRequest.from_dict(
            args)))


def update(args):
    return normalize(update_(
        json_body=kf_models_ssh_keys_key_update_request.ModelsSSHKeysKeyUpdateRequest.from_dict(
            args)))


def generate_key(args):
    return normalize(generate_key_(
        json_body=kf_models_ssh_keys_key_generation_request.ModelsSSHKeysKeyGenerationRequest.from_dict(
            args)))


def update_smtp(args):
    return normalize(update_smtp_(
        json_body=kf_keyfactor_api_models_smtpsmtp_request.KeyfactorAPIModelsSMTPSMTPRequest.from_dict(
            args)))


def test_smtp(args):
    return normalize(test_smtp_(
        json_body=kf_keyfactor_api_models_smtpsmtp_test_request.KeyfactorAPIModelsSMTPSMTPTestRequest.from_dict(
            args)))


def update_certificate_store_type(args):
    return normalize(update_certificate_store_type_(
        json_body=kf_keyfactor_api_models_certificate_stores_types_certificate_store_type_update_request.KeyfactorApiModelsCertificateStoresTypesCertificateStoreTypeUpdateRequest.from_dict(
            args)))


def create_certificate_store_type(args):
    return normalize(create_certificate_store_type_(
        json_body=kf_keyfactor_api_models_certificate_stores_types_certificate_store_type_creation_request.KeyfactorApiModelsCertificateStoresTypesCertificateStoreTypeCreationRequest.from_dict(
            args)))
